import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::AmplifyUIBuilder::Form Resource Type
 */
export declare function getForm(args: GetFormArgs, opts?: pulumi.InvokeOptions): Promise<GetFormResult>;
export interface GetFormArgs {
    /**
     * The unique ID of the Amplify app associated with the form.
     */
    appId: string;
    /**
     * The name of the backend environment that is a part of the Amplify app.
     */
    environmentName: string;
    /**
     * The ID for the form.
     */
    id: string;
}
export interface GetFormResult {
    /**
     * The `FormCTA` object that stores the call to action configuration for the form.
     */
    readonly cta?: outputs.amplifyuibuilder.FormCta;
    /**
     * The type of data source to use to create the form.
     */
    readonly dataType?: outputs.amplifyuibuilder.FormDataTypeConfig;
    /**
     * The configuration information for the form's fields.
     */
    readonly fields?: {
        [key: string]: outputs.amplifyuibuilder.FormFieldConfig;
    };
    /**
     * Specifies whether to perform a create or update action on the form.
     */
    readonly formActionType?: enums.amplifyuibuilder.FormActionType;
    /**
     * The ID for the form.
     */
    readonly id?: string;
    /**
     * Specifies an icon or decoration to display on the form.
     */
    readonly labelDecorator?: enums.amplifyuibuilder.FormLabelDecorator;
    /**
     * The name of the form.
     */
    readonly name?: string;
    /**
     * The schema version of the form.
     */
    readonly schemaVersion?: string;
    /**
     * The configuration information for the visual helper elements for the form. These elements are not associated with any data.
     */
    readonly sectionalElements?: {
        [key: string]: outputs.amplifyuibuilder.FormSectionalElement;
    };
    /**
     * The configuration for the form's style.
     */
    readonly style?: outputs.amplifyuibuilder.FormStyle;
    /**
     * One or more key-value pairs to use when tagging the form data.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * Definition of AWS::AmplifyUIBuilder::Form Resource Type
 */
export declare function getFormOutput(args: GetFormOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetFormResult>;
export interface GetFormOutputArgs {
    /**
     * The unique ID of the Amplify app associated with the form.
     */
    appId: pulumi.Input<string>;
    /**
     * The name of the backend environment that is a part of the Amplify app.
     */
    environmentName: pulumi.Input<string>;
    /**
     * The ID for the form.
     */
    id: pulumi.Input<string>;
}
