import * as pulumi from "@pulumi/pulumi";
/**
 * The ``AWS::ApiGatewayV2::Model`` resource updates data model for a WebSocket API. For more information, see [Model Selection Expressions](https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-api-selection-expressions.html#apigateway-websocket-api-model-selection-expressions) in the *API Gateway Developer Guide*.
 */
export declare function getModel(args: GetModelArgs, opts?: pulumi.InvokeOptions): Promise<GetModelResult>;
export interface GetModelArgs {
    /**
     * The API identifier.
     */
    apiId: string;
    /**
     * The model ID.
     */
    modelId: string;
}
export interface GetModelResult {
    /**
     * The content-type for the model, for example, "application/json".
     */
    readonly contentType?: string;
    /**
     * The description of the model.
     */
    readonly description?: string;
    /**
     * The model ID.
     */
    readonly modelId?: string;
    /**
     * The name of the model.
     */
    readonly name?: string;
    /**
     * The schema for the model. For application/json models, this should be JSON schema draft 4 model.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::ApiGatewayV2::Model` for more information about the expected schema for this property.
     */
    readonly schema?: any;
}
/**
 * The ``AWS::ApiGatewayV2::Model`` resource updates data model for a WebSocket API. For more information, see [Model Selection Expressions](https://docs.aws.amazon.com/apigateway/latest/developerguide/apigateway-websocket-api-selection-expressions.html#apigateway-websocket-api-model-selection-expressions) in the *API Gateway Developer Guide*.
 */
export declare function getModelOutput(args: GetModelOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetModelResult>;
export interface GetModelOutputArgs {
    /**
     * The API identifier.
     */
    apiId: pulumi.Input<string>;
    /**
     * The model ID.
     */
    modelId: pulumi.Input<string>;
}
