import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Type definition for AWS::AppConfig::HostedConfigurationVersion
 */
export declare class HostedConfigurationVersion extends pulumi.CustomResource {
    /**
     * Get an existing HostedConfigurationVersion resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): HostedConfigurationVersion;
    /**
     * Returns true if the given object is an instance of HostedConfigurationVersion.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is HostedConfigurationVersion;
    /**
     * The application ID.
     */
    readonly applicationId: pulumi.Output<string>;
    /**
     * The configuration profile ID.
     */
    readonly configurationProfileId: pulumi.Output<string>;
    /**
     * The content of the configuration or the configuration data.
     */
    readonly content: pulumi.Output<string>;
    /**
     * A standard MIME type describing the format of the configuration content.
     */
    readonly contentType: pulumi.Output<string>;
    /**
     * A description of the hosted configuration version.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * An optional locking token used to prevent race conditions from overwriting configuration updates when creating a new version. To ensure your data is not overwritten when creating multiple hosted configuration versions in rapid succession, specify the version number of the latest hosted configuration version.
     */
    readonly latestVersionNumber: pulumi.Output<number | undefined>;
    /**
     * A user-defined label for an AWS AppConfig hosted configuration version.
     */
    readonly versionLabel: pulumi.Output<string | undefined>;
    /**
     * Current version number of hosted configuration version.
     */
    readonly versionNumber: pulumi.Output<string>;
    /**
     * Create a HostedConfigurationVersion resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: HostedConfigurationVersionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a HostedConfigurationVersion resource.
 */
export interface HostedConfigurationVersionArgs {
    /**
     * The application ID.
     */
    applicationId: pulumi.Input<string>;
    /**
     * The configuration profile ID.
     */
    configurationProfileId: pulumi.Input<string>;
    /**
     * The content of the configuration or the configuration data.
     */
    content: pulumi.Input<string>;
    /**
     * A standard MIME type describing the format of the configuration content.
     */
    contentType: pulumi.Input<string>;
    /**
     * A description of the hosted configuration version.
     */
    description?: pulumi.Input<string>;
    /**
     * An optional locking token used to prevent race conditions from overwriting configuration updates when creating a new version. To ensure your data is not overwritten when creating multiple hosted configuration versions in rapid succession, specify the version number of the latest hosted configuration version.
     */
    latestVersionNumber?: pulumi.Input<number>;
    /**
     * A user-defined label for an AWS AppConfig hosted configuration version.
     */
    versionLabel?: pulumi.Input<string>;
}
