import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::Bedrock::Prompt Resource Type
 */
export declare class Prompt extends pulumi.CustomResource {
    /**
     * Get an existing Prompt resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Prompt;
    /**
     * Returns true if the given object is an instance of Prompt.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Prompt;
    /**
     * ARN of a prompt resource possibly with a version
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Identifier for a Prompt
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * Time Stamp.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * A KMS key ARN
     */
    readonly customerEncryptionKeyArn: pulumi.Output<string | undefined>;
    /**
     * Name for a variant.
     */
    readonly defaultVariant: pulumi.Output<string | undefined>;
    /**
     * Name for a prompt resource.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Name for a prompt resource.
     */
    readonly name: pulumi.Output<string>;
    /**
     * Metadata that you can assign to a resource as key-value pairs. For more information, see the following resources:
     *
     * - [Tag naming limits and requirements](https://docs.aws.amazon.com/tag-editor/latest/userguide/tagging.html#tag-conventions)
     * - [Tagging best practices](https://docs.aws.amazon.com/tag-editor/latest/userguide/tagging.html#tag-best-practices)
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Time Stamp.
     */
    readonly updatedAt: pulumi.Output<string>;
    /**
     * List of prompt variants
     */
    readonly variants: pulumi.Output<outputs.bedrock.PromptVariant[] | undefined>;
    /**
     * Draft Version.
     */
    readonly version: pulumi.Output<string>;
    /**
     * Create a Prompt resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: PromptArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Prompt resource.
 */
export interface PromptArgs {
    /**
     * A KMS key ARN
     */
    customerEncryptionKeyArn?: pulumi.Input<string>;
    /**
     * Name for a variant.
     */
    defaultVariant?: pulumi.Input<string>;
    /**
     * Name for a prompt resource.
     */
    description?: pulumi.Input<string>;
    /**
     * Name for a prompt resource.
     */
    name?: pulumi.Input<string>;
    /**
     * Metadata that you can assign to a resource as key-value pairs. For more information, see the following resources:
     *
     * - [Tag naming limits and requirements](https://docs.aws.amazon.com/tag-editor/latest/userguide/tagging.html#tag-conventions)
     * - [Tagging best practices](https://docs.aws.amazon.com/tag-editor/latest/userguide/tagging.html#tag-best-practices)
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * List of prompt variants
     */
    variants?: pulumi.Input<pulumi.Input<inputs.bedrock.PromptVariantArgs>[]>;
}
