import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Represents an association between an ID mapping workflow and a collaboration
 */
export declare class IdMappingTable extends pulumi.CustomResource {
    /**
     * Get an existing IdMappingTable resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): IdMappingTable;
    /**
     * Returns true if the given object is an instance of IdMappingTable.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is IdMappingTable;
    /**
     * The Amazon Resource Name (ARN) of the ID mapping table.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the collaboration that contains this ID mapping table.
     */
    readonly collaborationArn: pulumi.Output<string>;
    /**
     * The unique identifier of the collaboration that contains this ID mapping table.
     */
    readonly collaborationIdentifier: pulumi.Output<string>;
    /**
     * The description of the ID mapping table.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The unique identifier of the ID mapping table identifier that you want to retrieve.
     */
    readonly idMappingTableIdentifier: pulumi.Output<string>;
    /**
     * The input reference configuration for the ID mapping table.
     */
    readonly inputReferenceConfig: pulumi.Output<outputs.cleanrooms.IdMappingTableInputReferenceConfig>;
    readonly inputReferenceProperties: pulumi.Output<outputs.cleanrooms.IdMappingTableInputReferenceProperties>;
    /**
     * The Amazon Resource Name (ARN) of the AWS KMS key.
     */
    readonly kmsKeyArn: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the membership resource for the ID mapping table.
     */
    readonly membershipArn: pulumi.Output<string>;
    /**
     * The unique identifier of the membership resource for the ID mapping table.
     */
    readonly membershipIdentifier: pulumi.Output<string>;
    /**
     * The name of the ID mapping table.
     */
    readonly name: pulumi.Output<string>;
    /**
     * An optional label that you can assign to a resource when you create it. Each tag consists of a key and an optional value, both of which you define. When you use tagging, you can also use tag-based access control in IAM policies to control access to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a IdMappingTable resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: IdMappingTableArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a IdMappingTable resource.
 */
export interface IdMappingTableArgs {
    /**
     * The description of the ID mapping table.
     */
    description?: pulumi.Input<string>;
    /**
     * The input reference configuration for the ID mapping table.
     */
    inputReferenceConfig: pulumi.Input<inputs.cleanrooms.IdMappingTableInputReferenceConfigArgs>;
    /**
     * The Amazon Resource Name (ARN) of the AWS KMS key.
     */
    kmsKeyArn?: pulumi.Input<string>;
    /**
     * The unique identifier of the membership resource for the ID mapping table.
     */
    membershipIdentifier: pulumi.Input<string>;
    /**
     * The name of the ID mapping table.
     */
    name?: pulumi.Input<string>;
    /**
     * An optional label that you can assign to a resource when you create it. Each tag consists of a key and an optional value, both of which you define. When you use tagging, you can also use tag-based access control in IAM policies to control access to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
