import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * A key group.
 *  A key group contains a list of public keys that you can use with [CloudFront signed URLs and signed cookies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html).
 */
export declare function getKeyGroup(args: GetKeyGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetKeyGroupResult>;
export interface GetKeyGroupArgs {
    /**
     * The identifier for the key group.
     */
    id: string;
}
export interface GetKeyGroupResult {
    /**
     * The identifier for the key group.
     */
    readonly id?: string;
    /**
     * The key group configuration.
     */
    readonly keyGroupConfig?: outputs.cloudfront.KeyGroupConfig;
    /**
     * The date and time when the key group was last modified.
     */
    readonly lastModifiedTime?: string;
}
/**
 * A key group.
 *  A key group contains a list of public keys that you can use with [CloudFront signed URLs and signed cookies](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/PrivateContent.html).
 */
export declare function getKeyGroupOutput(args: GetKeyGroupOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetKeyGroupResult>;
export interface GetKeyGroupOutputArgs {
    /**
     * The identifier for the key group.
     */
    id: pulumi.Input<string>;
}
