import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for Metric Stream
 */
export declare function getMetricStream(args: GetMetricStreamArgs, opts?: pulumi.InvokeOptions): Promise<GetMetricStreamResult>;
export interface GetMetricStreamArgs {
    /**
     * Name of the metric stream.
     */
    name: string;
}
export interface GetMetricStreamResult {
    /**
     * Amazon Resource Name of the metric stream.
     */
    readonly arn?: string;
    /**
     * The date of creation of the metric stream.
     */
    readonly creationDate?: string;
    /**
     * Define which metrics will be not streamed. Metrics matched by multiple instances of MetricStreamFilter are joined with an OR operation by default. If both IncludeFilters and ExcludeFilters are omitted, all metrics in the account will be streamed. IncludeFilters and ExcludeFilters are mutually exclusive. Default to null.
     */
    readonly excludeFilters?: outputs.cloudwatch.MetricStreamFilter[];
    /**
     * The ARN of the Kinesis Firehose where to stream the data.
     */
    readonly firehoseArn?: string;
    /**
     * Define which metrics will be streamed. Metrics matched by multiple instances of MetricStreamFilter are joined with an OR operation by default. If both IncludeFilters and ExcludeFilters are omitted, all metrics in the account will be streamed. IncludeFilters and ExcludeFilters are mutually exclusive. Default to null.
     */
    readonly includeFilters?: outputs.cloudwatch.MetricStreamFilter[];
    /**
     * If you are creating a metric stream in a monitoring account, specify true to include metrics from source accounts that are linked to this monitoring account, in the metric stream. The default is false.
     */
    readonly includeLinkedAccountsMetrics?: boolean;
    /**
     * The date of the last update of the metric stream.
     */
    readonly lastUpdateDate?: string;
    /**
     * The output format of the data streamed to the Kinesis Firehose.
     */
    readonly outputFormat?: string;
    /**
     * The ARN of the role that provides access to the Kinesis Firehose.
     */
    readonly roleArn?: string;
    /**
     * Displays the state of the Metric Stream.
     */
    readonly state?: string;
    /**
     * By default, a metric stream always sends the MAX, MIN, SUM, and SAMPLECOUNT statistics for each metric that is streamed. You can use this parameter to have the metric stream also send additional statistics in the stream. This array can have up to 100 members.
     */
    readonly statisticsConfigurations?: outputs.cloudwatch.MetricStreamStatisticsConfiguration[];
    /**
     * A set of tags to assign to the delivery stream.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for Metric Stream
 */
export declare function getMetricStreamOutput(args: GetMetricStreamOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetMetricStreamResult>;
export interface GetMetricStreamOutputArgs {
    /**
     * Name of the metric stream.
     */
    name: pulumi.Input<string>;
}
