import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Connect::EmailAddress
 */
export declare class EmailAddress extends pulumi.CustomResource {
    /**
     * Get an existing EmailAddress resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): EmailAddress;
    /**
     * Returns true if the given object is an instance of EmailAddress.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EmailAddress;
    /**
     * A description for the email address.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The display name for the email address.
     */
    readonly displayName: pulumi.Output<string | undefined>;
    /**
     * Email address to be created for this instance
     */
    readonly emailAddress: pulumi.Output<string>;
    /**
     * The identifier of the email address.
     */
    readonly emailAddressArn: pulumi.Output<string>;
    /**
     * The identifier of the Amazon Connect instance.
     */
    readonly instanceArn: pulumi.Output<string>;
    /**
     * One or more tags.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a EmailAddress resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EmailAddressArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a EmailAddress resource.
 */
export interface EmailAddressArgs {
    /**
     * A description for the email address.
     */
    description?: pulumi.Input<string>;
    /**
     * The display name for the email address.
     */
    displayName?: pulumi.Input<string>;
    /**
     * Email address to be created for this instance
     */
    emailAddress: pulumi.Input<string>;
    /**
     * The identifier of the Amazon Connect instance.
     */
    instanceArn: pulumi.Input<string>;
    /**
     * One or more tags.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
