import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::Connect::TrafficDistributionGroup
 */
export declare class TrafficDistributionGroup extends pulumi.CustomResource {
    /**
     * Get an existing TrafficDistributionGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TrafficDistributionGroup;
    /**
     * Returns true if the given object is an instance of TrafficDistributionGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TrafficDistributionGroup;
    /**
     * A description for the traffic distribution group.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The identifier of the Amazon Connect instance that has been replicated.
     */
    readonly instanceArn: pulumi.Output<string>;
    /**
     * If this is the default traffic distribution group.
     */
    readonly isDefault: pulumi.Output<boolean>;
    /**
     * The name for the traffic distribution group.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The status of the traffic distribution group.
     */
    readonly status: pulumi.Output<enums.connect.TrafficDistributionGroupStatus>;
    /**
     * One or more tags.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The identifier of the traffic distribution group.
     */
    readonly trafficDistributionGroupArn: pulumi.Output<string>;
    /**
     * Create a TrafficDistributionGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TrafficDistributionGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TrafficDistributionGroup resource.
 */
export interface TrafficDistributionGroupArgs {
    /**
     * A description for the traffic distribution group.
     */
    description?: pulumi.Input<string>;
    /**
     * The identifier of the Amazon Connect instance that has been replicated.
     */
    instanceArn: pulumi.Input<string>;
    /**
     * The name for the traffic distribution group.
     */
    name?: pulumi.Input<string>;
    /**
     * One or more tags.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
