import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Connect::View
 */
export declare class View extends pulumi.CustomResource {
    /**
     * Get an existing View resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): View;
    /**
     * Returns true if the given object is an instance of View.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is View;
    /**
     * The actions of the view in an array.
     */
    readonly actions: pulumi.Output<string[]>;
    /**
     * The description of the view.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the instance.
     */
    readonly instanceArn: pulumi.Output<string>;
    /**
     * The name of the view.
     */
    readonly name: pulumi.Output<string>;
    /**
     * One or more tags.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The template of the view as JSON.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Connect::View` for more information about the expected schema for this property.
     */
    readonly template: pulumi.Output<any>;
    /**
     * The Amazon Resource Name (ARN) of the view.
     */
    readonly viewArn: pulumi.Output<string>;
    /**
     * The view content hash.
     */
    readonly viewContentSha256: pulumi.Output<string>;
    /**
     * The view id of the view.
     */
    readonly viewId: pulumi.Output<string>;
    /**
     * Create a View resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ViewArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a View resource.
 */
export interface ViewArgs {
    /**
     * The actions of the view in an array.
     */
    actions: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The description of the view.
     */
    description?: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the instance.
     */
    instanceArn: pulumi.Input<string>;
    /**
     * The name of the view.
     */
    name?: pulumi.Input<string>;
    /**
     * One or more tags.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The template of the view as JSON.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::Connect::View` for more information about the expected schema for this property.
     */
    template: any;
}
