import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::DataSync::LocationAzureBlob.
 */
export declare function getLocationAzureBlob(args: GetLocationAzureBlobArgs, opts?: pulumi.InvokeOptions): Promise<GetLocationAzureBlobResult>;
export interface GetLocationAzureBlobArgs {
    /**
     * The Amazon Resource Name (ARN) of the Azure Blob Location that is created.
     */
    locationArn: string;
}
export interface GetLocationAzureBlobResult {
    /**
     * The Amazon Resource Names (ARNs) of agents to use for an Azure Blob Location.
     */
    readonly agentArns?: string[];
    /**
     * Specifies an access tier for the objects you're transferring into your Azure Blob Storage container.
     */
    readonly azureAccessTier?: enums.datasync.LocationAzureBlobAzureAccessTier;
    /**
     * The specific authentication type that you want DataSync to use to access your Azure Blob Container.
     */
    readonly azureBlobAuthenticationType?: enums.datasync.LocationAzureBlobAzureBlobAuthenticationType;
    /**
     * Specifies a blob type for the objects you're transferring into your Azure Blob Storage container.
     */
    readonly azureBlobType?: enums.datasync.LocationAzureBlobAzureBlobType;
    /**
     * The Amazon Resource Name (ARN) of the Azure Blob Location that is created.
     */
    readonly locationArn?: string;
    /**
     * The URL of the Azure Blob Location that was described.
     */
    readonly locationUri?: string;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource schema for AWS::DataSync::LocationAzureBlob.
 */
export declare function getLocationAzureBlobOutput(args: GetLocationAzureBlobOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetLocationAzureBlobResult>;
export interface GetLocationAzureBlobOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the Azure Blob Location that is created.
     */
    locationArn: pulumi.Input<string>;
}
