import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Connections enables users to connect their DataZone resources (domains, projects, and environments) to external resources/services (data, compute, etc)
 */
export declare class Connection extends pulumi.CustomResource {
    /**
     * Get an existing Connection resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Connection;
    /**
     * Returns true if the given object is an instance of Connection.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Connection;
    /**
     * The location where the connection is created.
     */
    readonly awsLocation: pulumi.Output<outputs.datazone.ConnectionAwsLocation | undefined>;
    /**
     * The ID of the connection.
     */
    readonly connectionId: pulumi.Output<string>;
    /**
     * The description of the connection.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The ID of the domain in which the connection is created.
     */
    readonly domainId: pulumi.Output<string>;
    /**
     * The identifier of the domain in which the connection is created.
     */
    readonly domainIdentifier: pulumi.Output<string>;
    /**
     * The ID of the domain unit in which the connection is created.
     */
    readonly domainUnitId: pulumi.Output<string>;
    /**
     * The ID of the environment in which the connection is created.
     */
    readonly environmentId: pulumi.Output<string>;
    /**
     * The identifier of the environment in which the connection is created.
     */
    readonly environmentIdentifier: pulumi.Output<string>;
    /**
     * The role of the user in the environment.
     */
    readonly environmentUserRole: pulumi.Output<string>;
    /**
     * The name of the connection.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The ID of the project in which the connection is created.
     */
    readonly projectId: pulumi.Output<string>;
    /**
     * Connection props.
     */
    readonly props: pulumi.Output<outputs.datazone.ConnectionPropertiesInput0Properties | outputs.datazone.ConnectionPropertiesInput1Properties | outputs.datazone.ConnectionPropertiesInput2Properties | outputs.datazone.ConnectionPropertiesInput3Properties | outputs.datazone.ConnectionPropertiesInput4Properties | outputs.datazone.ConnectionPropertiesInput5Properties | outputs.datazone.ConnectionPropertiesInput6Properties | undefined>;
    /**
     * The type of the connection.
     */
    readonly type: pulumi.Output<string>;
    /**
     * Create a Connection resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ConnectionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Connection resource.
 */
export interface ConnectionArgs {
    /**
     * The location where the connection is created.
     */
    awsLocation?: pulumi.Input<inputs.datazone.ConnectionAwsLocationArgs>;
    /**
     * The description of the connection.
     */
    description?: pulumi.Input<string>;
    /**
     * The identifier of the domain in which the connection is created.
     */
    domainIdentifier: pulumi.Input<string>;
    /**
     * The identifier of the environment in which the connection is created.
     */
    environmentIdentifier: pulumi.Input<string>;
    /**
     * The name of the connection.
     */
    name?: pulumi.Input<string>;
    /**
     * Connection props.
     */
    props?: pulumi.Input<inputs.datazone.ConnectionPropertiesInput0PropertiesArgs | inputs.datazone.ConnectionPropertiesInput1PropertiesArgs | inputs.datazone.ConnectionPropertiesInput2PropertiesArgs | inputs.datazone.ConnectionPropertiesInput3PropertiesArgs | inputs.datazone.ConnectionPropertiesInput4PropertiesArgs | inputs.datazone.ConnectionPropertiesInput5PropertiesArgs | inputs.datazone.ConnectionPropertiesInput6PropertiesArgs>;
}
