import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Definition of AWS::DataZone::Environment Resource Type
 */
export declare function getEnvironment(args: GetEnvironmentArgs, opts?: pulumi.InvokeOptions): Promise<GetEnvironmentResult>;
export interface GetEnvironmentArgs {
    /**
     * The identifier of the Amazon DataZone domain in which the environment is created.
     */
    domainId: string;
    /**
     * The ID of the Amazon DataZone environment.
     */
    id: string;
}
export interface GetEnvironmentResult {
    /**
     * The AWS account in which the Amazon DataZone environment is created.
     */
    readonly awsAccountId?: string;
    /**
     * The AWS region in which the Amazon DataZone environment is created.
     */
    readonly awsAccountRegion?: string;
    /**
     * The timestamp of when the environment was created.
     */
    readonly createdAt?: string;
    /**
     * The Amazon DataZone user who created the environment.
     */
    readonly createdBy?: string;
    /**
     * The description of the Amazon DataZone environment.
     */
    readonly description?: string;
    /**
     * The identifier of the Amazon DataZone domain in which the environment is created.
     */
    readonly domainId?: string;
    /**
     * The ID of the blueprint with which the Amazon DataZone environment was created.
     */
    readonly environmentBlueprintId?: string;
    /**
     * The ID of the environment profile with which the Amazon DataZone environment was created.
     */
    readonly environmentProfileId?: string;
    /**
     * The glossary terms that can be used in the Amazon DataZone environment.
     */
    readonly glossaryTerms?: string[];
    /**
     * The ID of the Amazon DataZone environment.
     */
    readonly id?: string;
    /**
     * The name of the environment.
     */
    readonly name?: string;
    /**
     * The ID of the Amazon DataZone project in which the environment is created.
     */
    readonly projectId?: string;
    /**
     * The provider of the Amazon DataZone environment.
     */
    readonly provider?: string;
    /**
     * The status of the Amazon DataZone environment.
     */
    readonly status?: enums.datazone.EnvironmentStatus;
    /**
     * The timestamp of when the environment was updated.
     */
    readonly updatedAt?: string;
}
/**
 * Definition of AWS::DataZone::Environment Resource Type
 */
export declare function getEnvironmentOutput(args: GetEnvironmentOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetEnvironmentResult>;
export interface GetEnvironmentOutputArgs {
    /**
     * The identifier of the Amazon DataZone domain in which the environment is created.
     */
    domainId: pulumi.Input<string>;
    /**
     * The ID of the Amazon DataZone environment.
     */
    id: pulumi.Input<string>;
}
