import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Deadline::QueueEnvironment Resource Type
 */
export declare function getQueueEnvironment(args: GetQueueEnvironmentArgs, opts?: pulumi.InvokeOptions): Promise<GetQueueEnvironmentResult>;
export interface GetQueueEnvironmentArgs {
    /**
     * The identifier assigned to the farm that contains the queue.
     */
    farmId: string;
    /**
     * The queue environment ID.
     */
    queueEnvironmentId: string;
    /**
     * The unique identifier of the queue that contains the environment.
     */
    queueId: string;
}
export interface GetQueueEnvironmentResult {
    /**
     * The name of the queue environment.
     */
    readonly name?: string;
    /**
     * The queue environment's priority.
     */
    readonly priority?: number;
    /**
     * The queue environment ID.
     */
    readonly queueEnvironmentId?: string;
    /**
     * A JSON or YAML template that describes the processing environment for the queue.
     */
    readonly template?: string;
    /**
     * Specifies whether the template for the queue environment is JSON or YAML.
     */
    readonly templateType?: enums.deadline.QueueEnvironmentEnvironmentTemplateType;
}
/**
 * Definition of AWS::Deadline::QueueEnvironment Resource Type
 */
export declare function getQueueEnvironmentOutput(args: GetQueueEnvironmentOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetQueueEnvironmentResult>;
export interface GetQueueEnvironmentOutputArgs {
    /**
     * The identifier assigned to the farm that contains the queue.
     */
    farmId: pulumi.Input<string>;
    /**
     * The queue environment ID.
     */
    queueEnvironmentId: pulumi.Input<string>;
    /**
     * The unique identifier of the queue that contains the environment.
     */
    queueId: pulumi.Input<string>;
}
