import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::EC2::CapacityReservation
 */
export declare class CapacityReservation extends pulumi.CustomResource {
    /**
     * Get an existing CapacityReservation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): CapacityReservation;
    /**
     * Returns true if the given object is an instance of CapacityReservation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CapacityReservation;
    /**
     * The Availability Zone in which to create the Capacity Reservation.
     */
    readonly availabilityZone: pulumi.Output<string | undefined>;
    /**
     * The Availability Zone ID of the Capacity Reservation.
     */
    readonly availabilityZoneId: pulumi.Output<string | undefined>;
    /**
     * Returns the remaining capacity, which indicates the number of instances that can be launched in the Capacity Reservation. For example: `9` .
     */
    readonly availableInstanceCount: pulumi.Output<number>;
    /**
     * The ID of the Capacity Reservation.
     */
    readonly awsId: pulumi.Output<string>;
    readonly capacityAllocationSet: pulumi.Output<outputs.ec2.CapacityReservationCapacityAllocation[]>;
    /**
     * The Amazon Resource Name (ARN) of the Capacity Reservation.
     */
    readonly capacityReservationArn: pulumi.Output<string>;
    /**
     * The ID of the Capacity Reservation Fleet to which the Capacity Reservation belongs. Only valid for Capacity Reservations that were created by a Capacity Reservation Fleet.
     */
    readonly capacityReservationFleetId: pulumi.Output<string>;
    readonly commitmentInfo: pulumi.Output<outputs.ec2.CommitmentInfoProperties>;
    /**
     * The date and time at which the Capacity Reservation was created.
     */
    readonly createDate: pulumi.Output<string>;
    /**
     * The delivery method for a future-dated Capacity Reservation. `incremental` indicates that the requested capacity is delivered in addition to any running instances and reserved capacity that you have in your account at the requested date and time.
     */
    readonly deliveryPreference: pulumi.Output<string>;
    /**
     * Indicates whether the Capacity Reservation supports EBS-optimized instances. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS- optimized instance.
     */
    readonly ebsOptimized: pulumi.Output<boolean | undefined>;
    /**
     * The date and time at which the Capacity Reservation expires. When a Capacity Reservation expires, the reserved capacity is released and you can no longer launch instances into it. The Capacity Reservation's state changes to `expired` when it reaches its end date and time.
     *
     * You must provide an `EndDate` value if `EndDateType` is `limited` . Omit `EndDate` if `EndDateType` is `unlimited` .
     *
     * If the `EndDateType` is `limited` , the Capacity Reservation is cancelled within an hour from the specified time. For example, if you specify 5/31/2019, 13:30:55, the Capacity Reservation is guaranteed to end between 13:30:55 and 14:30:55 on 5/31/2019.
     *
     * If you are requesting a future-dated Capacity Reservation, you can't specify an end date and time that is within the commitment duration.
     */
    readonly endDate: pulumi.Output<string | undefined>;
    /**
     * Indicates the way in which the Capacity Reservation ends. A Capacity Reservation can have one of the following end types:
     *
     * - `unlimited` - The Capacity Reservation remains active until you explicitly cancel it. Do not provide an `EndDate` if the `EndDateType` is `unlimited` .
     * - `limited` - The Capacity Reservation expires automatically at a specified date and time. You must provide an `EndDate` value if the `EndDateType` value is `limited` .
     */
    readonly endDateType: pulumi.Output<string | undefined>;
    /**
     * *Deprecated.*
     */
    readonly ephemeralStorage: pulumi.Output<boolean | undefined>;
    /**
     * The number of instances for which to reserve capacity.
     *
     * > You can request future-dated Capacity Reservations for an instance count with a minimum of 100 vCPUs. For example, if you request a future-dated Capacity Reservation for `m5.xlarge` instances, you must request at least 25 instances ( *25 * m5.xlarge = 100 vCPUs* ).
     *
     * Valid range: 1 - 1000
     */
    readonly instanceCount: pulumi.Output<number>;
    /**
     * Indicates the type of instance launches that the Capacity Reservation accepts. The options include:
     *
     * - `open` - The Capacity Reservation automatically matches all instances that have matching attributes (instance type, platform, and Availability Zone). Instances that have matching attributes run in the Capacity Reservation automatically without specifying any additional parameters.
     * - `targeted` - The Capacity Reservation only accepts instances that have matching attributes (instance type, platform, and Availability Zone), and explicitly target the Capacity Reservation. This ensures that only permitted instances can use the reserved capacity.
     *
     * > If you are requesting a future-dated Capacity Reservation, you must specify `targeted` .
     *
     * Default: `open`
     */
    readonly instanceMatchCriteria: pulumi.Output<string | undefined>;
    /**
     * The type of operating system for which to reserve capacity.
     */
    readonly instancePlatform: pulumi.Output<string>;
    /**
     * The instance type for which to reserve capacity.
     *
     * > You can request future-dated Capacity Reservations for instance types in the C, M, R, I, and T instance families only.
     *
     * For more information, see [Instance types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html) in the *Amazon EC2 User Guide* .
     */
    readonly instanceType: pulumi.Output<string>;
    /**
     * > Not supported for future-dated Capacity Reservations.
     *
     * The Amazon Resource Name (ARN) of the Outpost on which to create the Capacity Reservation.
     */
    readonly outPostArn: pulumi.Output<string | undefined>;
    /**
     * The ID of the AWS account that owns the Capacity Reservation.
     */
    readonly ownerId: pulumi.Output<string>;
    /**
     * > Not supported for future-dated Capacity Reservations.
     *
     * The Amazon Resource Name (ARN) of the cluster placement group in which to create the Capacity Reservation. For more information, see [Capacity Reservations for cluster placement groups](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/cr-cpg.html) in the *Amazon EC2 User Guide* .
     */
    readonly placementGroupArn: pulumi.Output<string | undefined>;
    /**
     * The type of Capacity Reservation.
     */
    readonly reservationType: pulumi.Output<string>;
    /**
     * The date and time at which the Capacity Reservation was started.
     */
    readonly startDate: pulumi.Output<string>;
    /**
     * The current state of the Capacity Reservation. A Capacity Reservation can be in one of the following states:
     *
     * - `active` - The capacity is available for use.
     * - `expired` - The Capacity Reservation expired automatically at the date and time specified in your reservation request. The reserved capacity is no longer available for your use.
     * - `cancelled` - The Capacity Reservation was canceled. The reserved capacity is no longer available for your use.
     * - `pending` - The Capacity Reservation request was successful but the capacity provisioning is still pending.
     * - `failed` - The Capacity Reservation request has failed. A request can fail due to request parameters that are not valid, capacity constraints, or instance limit constraints. You can view a failed request for 60 minutes.
     * - `scheduled` - ( *Future-dated Capacity Reservations* ) The future-dated Capacity Reservation request was approved and the Capacity Reservation is scheduled for delivery on the requested start date.
     * - `payment-pending` - ( *Capacity Blocks* ) The upfront payment has not been processed yet.
     * - `payment-failed` - ( *Capacity Blocks* ) The upfront payment was not processed in the 12-hour time frame. Your Capacity Block was released.
     * - `assessing` - ( *Future-dated Capacity Reservations* ) Amazon EC2 is assessing your request for a future-dated Capacity Reservation.
     * - `delayed` - ( *Future-dated Capacity Reservations* ) Amazon EC2 encountered a delay in provisioning the requested future-dated Capacity Reservation. Amazon EC2 is unable to deliver the requested capacity by the requested start date and time.
     * - `unsupported` - ( *Future-dated Capacity Reservations* ) Amazon EC2 can't support the future-dated Capacity Reservation request due to capacity constraints. You can view unsupported requests for 30 days. The Capacity Reservation will not be delivered.
     */
    readonly state: pulumi.Output<string>;
    /**
     * The tags to apply to the Capacity Reservation during launch.
     */
    readonly tagSpecifications: pulumi.Output<outputs.ec2.CapacityReservationTagSpecification[] | undefined>;
    /**
     * Indicates the tenancy of the Capacity Reservation. A Capacity Reservation can have one of the following tenancy settings:
     *
     * - `default` - The Capacity Reservation is created on hardware that is shared with other AWS accounts .
     * - `dedicated` - The Capacity Reservation is created on single-tenant hardware that is dedicated to a single AWS account .
     */
    readonly tenancy: pulumi.Output<string | undefined>;
    /**
     * Returns the total number of instances for which the Capacity Reservation reserves capacity. For example: `15` .
     */
    readonly totalInstanceCount: pulumi.Output<number>;
    /**
     * The ID of the AWS account to which to assign billing of the unused capacity of the Capacity Reservation. A request will be sent to the specified account. That account must accept the request for the billing to be assigned to their account. For more information, see [Billing assignment for shared Amazon EC2 Capacity Reservations](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/assign-billing.html) .
     *
     * You can assign billing only for shared Capacity Reservations. To share a Capacity Reservation, you must add it to a resource share. For more information, see [AWS::RAM::ResourceShare](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ram-resourceshare.html) .
     */
    readonly unusedReservationBillingOwnerId: pulumi.Output<string | undefined>;
    /**
     * Create a CapacityReservation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CapacityReservationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a CapacityReservation resource.
 */
export interface CapacityReservationArgs {
    /**
     * The Availability Zone in which to create the Capacity Reservation.
     */
    availabilityZone?: pulumi.Input<string>;
    /**
     * The Availability Zone ID of the Capacity Reservation.
     */
    availabilityZoneId?: pulumi.Input<string>;
    /**
     * Indicates whether the Capacity Reservation supports EBS-optimized instances. This optimization provides dedicated throughput to Amazon EBS and an optimized configuration stack to provide optimal I/O performance. This optimization isn't available with all instance types. Additional usage charges apply when using an EBS- optimized instance.
     */
    ebsOptimized?: pulumi.Input<boolean>;
    /**
     * The date and time at which the Capacity Reservation expires. When a Capacity Reservation expires, the reserved capacity is released and you can no longer launch instances into it. The Capacity Reservation's state changes to `expired` when it reaches its end date and time.
     *
     * You must provide an `EndDate` value if `EndDateType` is `limited` . Omit `EndDate` if `EndDateType` is `unlimited` .
     *
     * If the `EndDateType` is `limited` , the Capacity Reservation is cancelled within an hour from the specified time. For example, if you specify 5/31/2019, 13:30:55, the Capacity Reservation is guaranteed to end between 13:30:55 and 14:30:55 on 5/31/2019.
     *
     * If you are requesting a future-dated Capacity Reservation, you can't specify an end date and time that is within the commitment duration.
     */
    endDate?: pulumi.Input<string>;
    /**
     * Indicates the way in which the Capacity Reservation ends. A Capacity Reservation can have one of the following end types:
     *
     * - `unlimited` - The Capacity Reservation remains active until you explicitly cancel it. Do not provide an `EndDate` if the `EndDateType` is `unlimited` .
     * - `limited` - The Capacity Reservation expires automatically at a specified date and time. You must provide an `EndDate` value if the `EndDateType` value is `limited` .
     */
    endDateType?: pulumi.Input<string>;
    /**
     * *Deprecated.*
     */
    ephemeralStorage?: pulumi.Input<boolean>;
    /**
     * The number of instances for which to reserve capacity.
     *
     * > You can request future-dated Capacity Reservations for an instance count with a minimum of 100 vCPUs. For example, if you request a future-dated Capacity Reservation for `m5.xlarge` instances, you must request at least 25 instances ( *25 * m5.xlarge = 100 vCPUs* ).
     *
     * Valid range: 1 - 1000
     */
    instanceCount: pulumi.Input<number>;
    /**
     * Indicates the type of instance launches that the Capacity Reservation accepts. The options include:
     *
     * - `open` - The Capacity Reservation automatically matches all instances that have matching attributes (instance type, platform, and Availability Zone). Instances that have matching attributes run in the Capacity Reservation automatically without specifying any additional parameters.
     * - `targeted` - The Capacity Reservation only accepts instances that have matching attributes (instance type, platform, and Availability Zone), and explicitly target the Capacity Reservation. This ensures that only permitted instances can use the reserved capacity.
     *
     * > If you are requesting a future-dated Capacity Reservation, you must specify `targeted` .
     *
     * Default: `open`
     */
    instanceMatchCriteria?: pulumi.Input<string>;
    /**
     * The type of operating system for which to reserve capacity.
     */
    instancePlatform: pulumi.Input<string>;
    /**
     * The instance type for which to reserve capacity.
     *
     * > You can request future-dated Capacity Reservations for instance types in the C, M, R, I, and T instance families only.
     *
     * For more information, see [Instance types](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/instance-types.html) in the *Amazon EC2 User Guide* .
     */
    instanceType: pulumi.Input<string>;
    /**
     * > Not supported for future-dated Capacity Reservations.
     *
     * The Amazon Resource Name (ARN) of the Outpost on which to create the Capacity Reservation.
     */
    outPostArn?: pulumi.Input<string>;
    /**
     * > Not supported for future-dated Capacity Reservations.
     *
     * The Amazon Resource Name (ARN) of the cluster placement group in which to create the Capacity Reservation. For more information, see [Capacity Reservations for cluster placement groups](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/cr-cpg.html) in the *Amazon EC2 User Guide* .
     */
    placementGroupArn?: pulumi.Input<string>;
    /**
     * The tags to apply to the Capacity Reservation during launch.
     */
    tagSpecifications?: pulumi.Input<pulumi.Input<inputs.ec2.CapacityReservationTagSpecificationArgs>[]>;
    /**
     * Indicates the tenancy of the Capacity Reservation. A Capacity Reservation can have one of the following tenancy settings:
     *
     * - `default` - The Capacity Reservation is created on hardware that is shared with other AWS accounts .
     * - `dedicated` - The Capacity Reservation is created on single-tenant hardware that is dedicated to a single AWS account .
     */
    tenancy?: pulumi.Input<string>;
    /**
     * The ID of the AWS account to which to assign billing of the unused capacity of the Capacity Reservation. A request will be sent to the specified account. That account must accept the request for the billing to be assigned to their account. For more information, see [Billing assignment for shared Amazon EC2 Capacity Reservations](https://docs.aws.amazon.com/AWSEC2/latest/UserGuide/assign-billing.html) .
     *
     * You can assign billing only for shared Capacity Reservations. To share a Capacity Reservation, you must add it to a resource share. For more information, see [AWS::RAM::ResourceShare](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-resource-ram-resourceshare.html) .
     */
    unusedReservationBillingOwnerId?: pulumi.Input<string>;
}
