import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Schema of AWS::EC2::IPAMScope Type
 */
export declare function getIpamScope(args: GetIpamScopeArgs, opts?: pulumi.InvokeOptions): Promise<GetIpamScopeResult>;
export interface GetIpamScopeArgs {
    /**
     * Id of the IPAM scope.
     */
    ipamScopeId: string;
}
export interface GetIpamScopeResult {
    /**
     * The Amazon Resource Name (ARN) of the IPAM scope.
     */
    readonly arn?: string;
    /**
     * The description of the scope.
     */
    readonly description?: string;
    /**
     * The Amazon Resource Name (ARN) of the IPAM this scope is a part of.
     */
    readonly ipamArn?: string;
    /**
     * Id of the IPAM scope.
     */
    readonly ipamScopeId?: string;
    /**
     * Determines whether this scope contains publicly routable space or space for a private network
     */
    readonly ipamScopeType?: enums.ec2.IpamScopeType;
    /**
     * Is this one of the default scopes created with the IPAM.
     */
    readonly isDefault?: boolean;
    /**
     * The number of pools that currently exist in this scope.
     */
    readonly poolCount?: number;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Schema of AWS::EC2::IPAMScope Type
 */
export declare function getIpamScopeOutput(args: GetIpamScopeOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetIpamScopeResult>;
export interface GetIpamScopeOutputArgs {
    /**
     * Id of the IPAM scope.
     */
    ipamScopeId: pulumi.Input<string>;
}
