import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The AWS::EC2::VerifiedAccessInstance resource creates an AWS EC2 Verified Access Instance.
 */
export declare function getVerifiedAccessInstance(args: GetVerifiedAccessInstanceArgs, opts?: pulumi.InvokeOptions): Promise<GetVerifiedAccessInstanceResult>;
export interface GetVerifiedAccessInstanceArgs {
    /**
     * The ID of the AWS Verified Access instance.
     */
    verifiedAccessInstanceId: string;
}
export interface GetVerifiedAccessInstanceResult {
    /**
     * Introduce CidrEndpointsCustomSubDomain property to represent the domain (say, ava.my-company.com)
     */
    readonly cidrEndpointsCustomSubDomain?: string;
    /**
     * Property to represent the name servers assoicated with the domain that AVA manages (say, ['ns1.amazonaws.com', 'ns2.amazonaws.com', 'ns3.amazonaws.com', 'ns4.amazonaws.com']).
     */
    readonly cidrEndpointsCustomSubDomainNameServers?: string[];
    /**
     * Time this Verified Access Instance was created.
     */
    readonly creationTime?: string;
    /**
     * A description for the AWS Verified Access instance.
     */
    readonly description?: string;
    /**
     * Indicates whether FIPS is enabled
     */
    readonly fipsEnabled?: boolean;
    /**
     * Time this Verified Access Instance was last updated.
     */
    readonly lastUpdatedTime?: string;
    /**
     * The configuration options for AWS Verified Access instances.
     */
    readonly loggingConfigurations?: outputs.ec2.VerifiedAccessInstanceVerifiedAccessLogs;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The ID of the AWS Verified Access instance.
     */
    readonly verifiedAccessInstanceId?: string;
    /**
     * The IDs of the AWS Verified Access trust providers.
     */
    readonly verifiedAccessTrustProviderIds?: string[];
    /**
     * AWS Verified Access trust providers.
     */
    readonly verifiedAccessTrustProviders?: outputs.ec2.VerifiedAccessInstanceVerifiedAccessTrustProvider[];
}
/**
 * The AWS::EC2::VerifiedAccessInstance resource creates an AWS EC2 Verified Access Instance.
 */
export declare function getVerifiedAccessInstanceOutput(args: GetVerifiedAccessInstanceOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetVerifiedAccessInstanceResult>;
export interface GetVerifiedAccessInstanceOutputArgs {
    /**
     * The ID of the AWS Verified Access instance.
     */
    verifiedAccessInstanceId: pulumi.Input<string>;
}
