import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Resource type definition for the AWS::EC2::SecurityGroupVpcAssociation resource
 */
export declare class SecurityGroupVpcAssociation extends pulumi.CustomResource {
    /**
     * Get an existing SecurityGroupVpcAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): SecurityGroupVpcAssociation;
    /**
     * Returns true if the given object is an instance of SecurityGroupVpcAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SecurityGroupVpcAssociation;
    /**
     * The group ID of the specified security group.
     */
    readonly groupId: pulumi.Output<string>;
    /**
     * The state of the security group vpc association.
     */
    readonly state: pulumi.Output<enums.ec2.SecurityGroupVpcAssociationState>;
    /**
     * The reason for the state of the security group vpc association.
     */
    readonly stateReason: pulumi.Output<string>;
    /**
     * The ID of the VPC in the security group vpc association.
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * The owner of the VPC in the security group vpc association.
     */
    readonly vpcOwnerId: pulumi.Output<string>;
    /**
     * Create a SecurityGroupVpcAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SecurityGroupVpcAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a SecurityGroupVpcAssociation resource.
 */
export interface SecurityGroupVpcAssociationArgs {
    /**
     * The group ID of the specified security group.
     */
    groupId: pulumi.Input<string>;
    /**
     * The ID of the VPC in the security group vpc association.
     */
    vpcId: pulumi.Input<string>;
}
