import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * The AWS::ElastiCache::GlobalReplicationGroup resource creates an Amazon ElastiCache Global Replication Group.
 */
export declare class GlobalReplicationGroup extends pulumi.CustomResource {
    /**
     * Get an existing GlobalReplicationGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): GlobalReplicationGroup;
    /**
     * Returns true if the given object is an instance of GlobalReplicationGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is GlobalReplicationGroup;
    /**
     * AutomaticFailoverEnabled
     */
    readonly automaticFailoverEnabled: pulumi.Output<boolean | undefined>;
    /**
     * The cache node type of the Global Datastore
     */
    readonly cacheNodeType: pulumi.Output<string | undefined>;
    /**
     * Cache parameter group name to use for the new engine version. This parameter cannot be modified independently.
     */
    readonly cacheParameterGroupName: pulumi.Output<string | undefined>;
    /**
     * The engine of the Global Datastore.
     */
    readonly engine: pulumi.Output<string | undefined>;
    /**
     * The engine version of the Global Datastore.
     */
    readonly engineVersion: pulumi.Output<string | undefined>;
    /**
     * Indicates the number of node groups in the Global Datastore.
     */
    readonly globalNodeGroupCount: pulumi.Output<number | undefined>;
    /**
     * The optional description of the Global Datastore
     */
    readonly globalReplicationGroupDescription: pulumi.Output<string | undefined>;
    /**
     * The name of the Global Datastore, it is generated by ElastiCache adding a prefix to GlobalReplicationGroupIdSuffix.
     */
    readonly globalReplicationGroupId: pulumi.Output<string>;
    /**
     * The suffix name of a Global Datastore. Amazon ElastiCache automatically applies a prefix to the Global Datastore ID when it is created. Each AWS Region has its own prefix.
     */
    readonly globalReplicationGroupIdSuffix: pulumi.Output<string | undefined>;
    /**
     * The replication groups that comprise the Global Datastore.
     */
    readonly members: pulumi.Output<outputs.elasticache.GlobalReplicationGroupMember[]>;
    /**
     * Describes the replication group IDs, the AWS regions where they are stored and the shard configuration for each that comprise the Global Datastore
     */
    readonly regionalConfigurations: pulumi.Output<outputs.elasticache.GlobalReplicationGroupRegionalConfiguration[] | undefined>;
    /**
     * The status of the Global Datastore
     */
    readonly status: pulumi.Output<string>;
    /**
     * Create a GlobalReplicationGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: GlobalReplicationGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a GlobalReplicationGroup resource.
 */
export interface GlobalReplicationGroupArgs {
    /**
     * AutomaticFailoverEnabled
     */
    automaticFailoverEnabled?: pulumi.Input<boolean>;
    /**
     * The cache node type of the Global Datastore
     */
    cacheNodeType?: pulumi.Input<string>;
    /**
     * Cache parameter group name to use for the new engine version. This parameter cannot be modified independently.
     */
    cacheParameterGroupName?: pulumi.Input<string>;
    /**
     * The engine of the Global Datastore.
     */
    engine?: pulumi.Input<string>;
    /**
     * The engine version of the Global Datastore.
     */
    engineVersion?: pulumi.Input<string>;
    /**
     * Indicates the number of node groups in the Global Datastore.
     */
    globalNodeGroupCount?: pulumi.Input<number>;
    /**
     * The optional description of the Global Datastore
     */
    globalReplicationGroupDescription?: pulumi.Input<string>;
    /**
     * The suffix name of a Global Datastore. Amazon ElastiCache automatically applies a prefix to the Global Datastore ID when it is created. Each AWS Region has its own prefix.
     */
    globalReplicationGroupIdSuffix?: pulumi.Input<string>;
    /**
     * The replication groups that comprise the Global Datastore.
     */
    members: pulumi.Input<pulumi.Input<inputs.elasticache.GlobalReplicationGroupMemberArgs>[]>;
    /**
     * Describes the replication group IDs, the AWS regions where they are stored and the shard configuration for each that comprise the Global Datastore
     */
    regionalConfigurations?: pulumi.Input<pulumi.Input<inputs.elasticache.GlobalReplicationGroupRegionalConfigurationArgs>[]>;
}
