import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Specifies an Application Load Balancer, a Network Load Balancer, or a Gateway Load Balancer.
 */
export declare class LoadBalancer extends pulumi.CustomResource {
    /**
     * Get an existing LoadBalancer resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): LoadBalancer;
    /**
     * Returns true if the given object is an instance of LoadBalancer.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LoadBalancer;
    /**
     * The ID of the Amazon Route 53 hosted zone associated with the load balancer. For example, `Z2P70J7EXAMPLE` .
     */
    readonly canonicalHostedZoneId: pulumi.Output<string>;
    /**
     * The DNS name for the load balancer. For example, `my-load-balancer-424835706.us-west-2.elb.amazonaws.com` .
     */
    readonly dnsName: pulumi.Output<string>;
    /**
     * [Network Load Balancers with UDP listeners] Indicates whether to use an IPv6 prefix from each subnet for source NAT. The IP address type must be ``dualstack``. The default value is ``off``.
     */
    readonly enablePrefixForIpv6SourceNat: pulumi.Output<string | undefined>;
    /**
     * Indicates whether to evaluate inbound security group rules for traffic sent to a Network Load Balancer through privatelink. The default is ``on``.
     */
    readonly enforceSecurityGroupInboundRulesOnPrivateLinkTraffic: pulumi.Output<string | undefined>;
    /**
     * The IP address type. Internal load balancers must use ``ipv4``.
     *  [Application Load Balancers] The possible values are ``ipv4`` (IPv4 addresses), ``dualstack`` (IPv4 and IPv6 addresses), and ``dualstack-without-public-ipv4`` (public IPv6 addresses and private IPv4 and IPv6 addresses).
     *  Application Load Balancer authentication supports IPv4 addresses only when connecting to an Identity Provider (IdP) or Amazon Cognito endpoint. Without a public IPv4 address the load balancer can't complete the authentication process, resulting in HTTP 500 errors.
     *  [Network Load Balancers and Gateway Load Balancers] The possible values are ``ipv4`` (IPv4 addresses) and ``dualstack`` (IPv4 and IPv6 addresses).
     */
    readonly ipAddressType: pulumi.Output<string | undefined>;
    readonly ipv4IpamPoolId: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the load balancer.
     */
    readonly loadBalancerArn: pulumi.Output<string>;
    /**
     * The load balancer attributes.
     */
    readonly loadBalancerAttributes: pulumi.Output<outputs.elasticloadbalancingv2.LoadBalancerAttribute[] | undefined>;
    /**
     * The full name of the load balancer. For example, `app/my-load-balancer/50dc6c495c0c9188` .
     */
    readonly loadBalancerFullName: pulumi.Output<string>;
    /**
     * The name of the load balancer. For example, `my-load-balancer` .
     */
    readonly loadBalancerName: pulumi.Output<string>;
    /**
     * The minimum capacity for a load balancer.
     */
    readonly minimumLoadBalancerCapacity: pulumi.Output<outputs.elasticloadbalancingv2.LoadBalancerMinimumLoadBalancerCapacity | undefined>;
    /**
     * The name of the load balancer. This name must be unique per region per account, can have a maximum of 32 characters, must contain only alphanumeric characters or hyphens, must not begin or end with a hyphen, and must not begin with "internal-".
     *  If you don't specify a name, AWS CloudFormation generates a unique physical ID for the load balancer. If you specify a name, you cannot perform updates that require replacement of this resource, but you can perform other updates. To replace the resource, specify a new name.
     */
    readonly name: pulumi.Output<string | undefined>;
    /**
     * The nodes of an Internet-facing load balancer have public IP addresses. The DNS name of an Internet-facing load balancer is publicly resolvable to the public IP addresses of the nodes. Therefore, Internet-facing load balancers can route requests from clients over the internet.
     *  The nodes of an internal load balancer have only private IP addresses. The DNS name of an internal load balancer is publicly resolvable to the private IP addresses of the nodes. Therefore, internal load balancers can route requests only from clients with access to the VPC for the load balancer.
     *  The default is an Internet-facing load balancer.
     *  You can't specify a scheme for a Gateway Load Balancer.
     */
    readonly scheme: pulumi.Output<string | undefined>;
    /**
     * [Application Load Balancers and Network Load Balancers] The IDs of the security groups for the load balancer.
     */
    readonly securityGroups: pulumi.Output<string[] | undefined>;
    /**
     * The IDs of the subnets. You can specify only one subnet per Availability Zone. You must specify either subnets or subnet mappings, but not both.
     *  [Application Load Balancers] You must specify subnets from at least two Availability Zones. You can't specify Elastic IP addresses for your subnets.
     *  [Application Load Balancers on Outposts] You must specify one Outpost subnet.
     *  [Application Load Balancers on Local Zones] You can specify subnets from one or more Local Zones.
     *  [Network Load Balancers] You can specify subnets from one or more Availability Zones. You can specify one Elastic IP address per subnet if you need static IP addresses for your internet-facing load balancer. For internal load balancers, you can specify one private IP address per subnet from the IPv4 range of the subnet. For internet-facing load balancer, you can specify one IPv6 address per subnet.
     *  [Gateway Load Balancers] You can specify subnets from one or more Availability Zones. You can't specify Elastic IP addresses for your subnets.
     */
    readonly subnetMappings: pulumi.Output<outputs.elasticloadbalancingv2.LoadBalancerSubnetMapping[] | undefined>;
    /**
     * The IDs of the subnets. You can specify only one subnet per Availability Zone. You must specify either subnets or subnet mappings, but not both. To specify an Elastic IP address, specify subnet mappings instead of subnets.
     *  [Application Load Balancers] You must specify subnets from at least two Availability Zones.
     *  [Application Load Balancers on Outposts] You must specify one Outpost subnet.
     *  [Application Load Balancers on Local Zones] You can specify subnets from one or more Local Zones.
     *  [Network Load Balancers and Gateway Load Balancers] You can specify subnets from one or more Availability Zones.
     */
    readonly subnets: pulumi.Output<string[] | undefined>;
    /**
     * The tags to assign to the load balancer.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The type of load balancer. The default is ``application``.
     */
    readonly type: pulumi.Output<string | undefined>;
    /**
     * Create a LoadBalancer resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: LoadBalancerArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a LoadBalancer resource.
 */
export interface LoadBalancerArgs {
    /**
     * [Network Load Balancers with UDP listeners] Indicates whether to use an IPv6 prefix from each subnet for source NAT. The IP address type must be ``dualstack``. The default value is ``off``.
     */
    enablePrefixForIpv6SourceNat?: pulumi.Input<string>;
    /**
     * Indicates whether to evaluate inbound security group rules for traffic sent to a Network Load Balancer through privatelink. The default is ``on``.
     */
    enforceSecurityGroupInboundRulesOnPrivateLinkTraffic?: pulumi.Input<string>;
    /**
     * The IP address type. Internal load balancers must use ``ipv4``.
     *  [Application Load Balancers] The possible values are ``ipv4`` (IPv4 addresses), ``dualstack`` (IPv4 and IPv6 addresses), and ``dualstack-without-public-ipv4`` (public IPv6 addresses and private IPv4 and IPv6 addresses).
     *  Application Load Balancer authentication supports IPv4 addresses only when connecting to an Identity Provider (IdP) or Amazon Cognito endpoint. Without a public IPv4 address the load balancer can't complete the authentication process, resulting in HTTP 500 errors.
     *  [Network Load Balancers and Gateway Load Balancers] The possible values are ``ipv4`` (IPv4 addresses) and ``dualstack`` (IPv4 and IPv6 addresses).
     */
    ipAddressType?: pulumi.Input<string>;
    ipv4IpamPoolId?: pulumi.Input<string>;
    /**
     * The load balancer attributes.
     */
    loadBalancerAttributes?: pulumi.Input<pulumi.Input<inputs.elasticloadbalancingv2.LoadBalancerAttributeArgs>[]>;
    /**
     * The minimum capacity for a load balancer.
     */
    minimumLoadBalancerCapacity?: pulumi.Input<inputs.elasticloadbalancingv2.LoadBalancerMinimumLoadBalancerCapacityArgs>;
    /**
     * The name of the load balancer. This name must be unique per region per account, can have a maximum of 32 characters, must contain only alphanumeric characters or hyphens, must not begin or end with a hyphen, and must not begin with "internal-".
     *  If you don't specify a name, AWS CloudFormation generates a unique physical ID for the load balancer. If you specify a name, you cannot perform updates that require replacement of this resource, but you can perform other updates. To replace the resource, specify a new name.
     */
    name?: pulumi.Input<string>;
    /**
     * The nodes of an Internet-facing load balancer have public IP addresses. The DNS name of an Internet-facing load balancer is publicly resolvable to the public IP addresses of the nodes. Therefore, Internet-facing load balancers can route requests from clients over the internet.
     *  The nodes of an internal load balancer have only private IP addresses. The DNS name of an internal load balancer is publicly resolvable to the private IP addresses of the nodes. Therefore, internal load balancers can route requests only from clients with access to the VPC for the load balancer.
     *  The default is an Internet-facing load balancer.
     *  You can't specify a scheme for a Gateway Load Balancer.
     */
    scheme?: pulumi.Input<string>;
    /**
     * [Application Load Balancers and Network Load Balancers] The IDs of the security groups for the load balancer.
     */
    securityGroups?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The IDs of the subnets. You can specify only one subnet per Availability Zone. You must specify either subnets or subnet mappings, but not both.
     *  [Application Load Balancers] You must specify subnets from at least two Availability Zones. You can't specify Elastic IP addresses for your subnets.
     *  [Application Load Balancers on Outposts] You must specify one Outpost subnet.
     *  [Application Load Balancers on Local Zones] You can specify subnets from one or more Local Zones.
     *  [Network Load Balancers] You can specify subnets from one or more Availability Zones. You can specify one Elastic IP address per subnet if you need static IP addresses for your internet-facing load balancer. For internal load balancers, you can specify one private IP address per subnet from the IPv4 range of the subnet. For internet-facing load balancer, you can specify one IPv6 address per subnet.
     *  [Gateway Load Balancers] You can specify subnets from one or more Availability Zones. You can't specify Elastic IP addresses for your subnets.
     */
    subnetMappings?: pulumi.Input<pulumi.Input<inputs.elasticloadbalancingv2.LoadBalancerSubnetMappingArgs>[]>;
    /**
     * The IDs of the subnets. You can specify only one subnet per Availability Zone. You must specify either subnets or subnet mappings, but not both. To specify an Elastic IP address, specify subnet mappings instead of subnets.
     *  [Application Load Balancers] You must specify subnets from at least two Availability Zones.
     *  [Application Load Balancers on Outposts] You must specify one Outpost subnet.
     *  [Application Load Balancers on Local Zones] You can specify subnets from one or more Local Zones.
     *  [Network Load Balancers and Gateway Load Balancers] You can specify subnets from one or more Availability Zones.
     */
    subnets?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The tags to assign to the load balancer.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The type of load balancer. The default is ``application``.
     */
    type?: pulumi.Input<string>;
}
