import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::GlobalAccelerator::Listener
 */
export declare class Listener extends pulumi.CustomResource {
    /**
     * Get an existing Listener resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Listener;
    /**
     * Returns true if the given object is an instance of Listener.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Listener;
    /**
     * The Amazon Resource Name (ARN) of the accelerator.
     */
    readonly acceleratorArn: pulumi.Output<string>;
    /**
     * Client affinity lets you direct all requests from a user to the same endpoint.
     */
    readonly clientAffinity: pulumi.Output<enums.globalaccelerator.ListenerClientAffinity | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the listener.
     */
    readonly listenerArn: pulumi.Output<string>;
    /**
     * The list of port ranges for the connections from clients to the accelerator.
     */
    readonly portRanges: pulumi.Output<outputs.globalaccelerator.ListenerPortRange[]>;
    /**
     * The protocol for the listener.
     */
    readonly protocol: pulumi.Output<enums.globalaccelerator.ListenerProtocol>;
    /**
     * Create a Listener resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ListenerArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Listener resource.
 */
export interface ListenerArgs {
    /**
     * The Amazon Resource Name (ARN) of the accelerator.
     */
    acceleratorArn: pulumi.Input<string>;
    /**
     * Client affinity lets you direct all requests from a user to the same endpoint.
     */
    clientAffinity?: pulumi.Input<enums.globalaccelerator.ListenerClientAffinity>;
    /**
     * The list of port ranges for the connections from clients to the accelerator.
     */
    portRanges: pulumi.Input<pulumi.Input<inputs.globalaccelerator.ListenerPortRangeArgs>[]>;
    /**
     * The protocol for the listener.
     */
    protocol: pulumi.Input<enums.globalaccelerator.ListenerProtocol>;
}
