import * as pulumi from "@pulumi/pulumi";
/**
 * GuardDuty Master resource schema
 */
export declare class Master extends pulumi.CustomResource {
    /**
     * Get an existing Master resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Master;
    /**
     * Returns true if the given object is an instance of Master.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Master;
    /**
     * Unique ID of the detector of the GuardDuty member account.
     */
    readonly detectorId: pulumi.Output<string>;
    /**
     * Value used to validate the master account to the member account.
     */
    readonly invitationId: pulumi.Output<string | undefined>;
    /**
     * ID of the account used as the master account.
     */
    readonly masterId: pulumi.Output<string>;
    /**
     * Create a Master resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MasterArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Master resource.
 */
export interface MasterArgs {
    /**
     * Unique ID of the detector of the GuardDuty member account.
     */
    detectorId: pulumi.Input<string>;
    /**
     * Value used to validate the master account to the member account.
     */
    invitationId?: pulumi.Input<string>;
    /**
     * ID of the account used as the master account.
     */
    masterId: pulumi.Input<string>;
}
