import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::IoT::BillingGroup
 */
export declare class BillingGroup extends pulumi.CustomResource {
    /**
     * Get an existing BillingGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): BillingGroup;
    /**
     * Returns true if the given object is an instance of BillingGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is BillingGroup;
    /**
     * The ARN of the billing group.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The ID of the billing group.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The name of the billing group.
     */
    readonly billingGroupName: pulumi.Output<string | undefined>;
    /**
     * The properties of the billing group.
     */
    readonly billingGroupProperties: pulumi.Output<outputs.iot.BillingGroupPropertiesProperties | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a BillingGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: BillingGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a BillingGroup resource.
 */
export interface BillingGroupArgs {
    /**
     * The name of the billing group.
     */
    billingGroupName?: pulumi.Input<string>;
    /**
     * The properties of the billing group.
     */
    billingGroupProperties?: pulumi.Input<inputs.iot.BillingGroupPropertiesPropertiesArgs>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
