import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Resource-specific logging allows you to specify a logging level for a specific thing group.
 */
export declare class ResourceSpecificLogging extends pulumi.CustomResource {
    /**
     * Get an existing ResourceSpecificLogging resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ResourceSpecificLogging;
    /**
     * Returns true if the given object is an instance of ResourceSpecificLogging.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ResourceSpecificLogging;
    /**
     * The log level for a specific target. Valid values are: ERROR, WARN, INFO, DEBUG, or DISABLED.
     */
    readonly logLevel: pulumi.Output<enums.iot.ResourceSpecificLoggingLogLevel>;
    /**
     * Unique Id for a Target (TargetType:TargetName), this will be internally built to serve as primary identifier for a log target.
     */
    readonly targetId: pulumi.Output<string>;
    /**
     * The target name.
     */
    readonly targetName: pulumi.Output<string>;
    /**
     * The target type. Value must be THING_GROUP, CLIENT_ID, SOURCE_IP, PRINCIPAL_ID, or EVENT_TYPE.
     */
    readonly targetType: pulumi.Output<enums.iot.ResourceSpecificLoggingTargetType>;
    /**
     * Create a ResourceSpecificLogging resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ResourceSpecificLoggingArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ResourceSpecificLogging resource.
 */
export interface ResourceSpecificLoggingArgs {
    /**
     * The log level for a specific target. Valid values are: ERROR, WARN, INFO, DEBUG, or DISABLED.
     */
    logLevel: pulumi.Input<enums.iot.ResourceSpecificLoggingLogLevel>;
    /**
     * The target name.
     */
    targetName: pulumi.Input<string>;
    /**
     * The target type. Value must be THING_GROUP, CLIENT_ID, SOURCE_IP, PRINCIPAL_ID, or EVENT_TYPE.
     */
    targetType: pulumi.Input<enums.iot.ResourceSpecificLoggingTargetType>;
}
