import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::IoTSiteWise::AccessPolicy
 */
export declare class AccessPolicy extends pulumi.CustomResource {
    /**
     * Get an existing AccessPolicy resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): AccessPolicy;
    /**
     * Returns true if the given object is an instance of AccessPolicy.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AccessPolicy;
    /**
     * The ARN of the access policy.
     */
    readonly accessPolicyArn: pulumi.Output<string>;
    /**
     * The ID of the access policy.
     */
    readonly accessPolicyId: pulumi.Output<string>;
    /**
     * The identity for this access policy. Choose either a user or a group but not both.
     */
    readonly accessPolicyIdentity: pulumi.Output<outputs.iotsitewise.AccessPolicyIdentity>;
    /**
     * The permission level for this access policy. Valid values are ADMINISTRATOR or VIEWER.
     */
    readonly accessPolicyPermission: pulumi.Output<string>;
    /**
     * The AWS IoT SiteWise Monitor resource for this access policy. Choose either portal or project but not both.
     */
    readonly accessPolicyResource: pulumi.Output<outputs.iotsitewise.AccessPolicyResource>;
    /**
     * Create a AccessPolicy resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AccessPolicyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a AccessPolicy resource.
 */
export interface AccessPolicyArgs {
    /**
     * The identity for this access policy. Choose either a user or a group but not both.
     */
    accessPolicyIdentity: pulumi.Input<inputs.iotsitewise.AccessPolicyIdentityArgs>;
    /**
     * The permission level for this access policy. Valid values are ADMINISTRATOR or VIEWER.
     */
    accessPolicyPermission: pulumi.Input<string>;
    /**
     * The AWS IoT SiteWise Monitor resource for this access policy. Choose either portal or project but not both.
     */
    accessPolicyResource: pulumi.Input<inputs.iotsitewise.AccessPolicyResourceArgs>;
}
