import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type Definition for AWS::KinesisVideo::Stream
 */
export declare function getStream(args: GetStreamArgs, opts?: pulumi.InvokeOptions): Promise<GetStreamResult>;
export interface GetStreamArgs {
    /**
     * The name of the Kinesis Video stream.
     */
    name: string;
}
export interface GetStreamResult {
    /**
     * The Amazon Resource Name (ARN) of the Kinesis Video stream.
     */
    readonly arn?: string;
    /**
     * The number of hours till which Kinesis Video will retain the data in the stream
     */
    readonly dataRetentionInHours?: number;
    /**
     * The name of the device that is writing to the stream.
     */
    readonly deviceName?: string;
    /**
     * AWS KMS key ID that Kinesis Video Streams uses to encrypt stream data.
     */
    readonly kmsKeyId?: string;
    /**
     * The media type of the stream. Consumers of the stream can use this information when processing the stream.
     */
    readonly mediaType?: string;
    /**
     * An array of key-value pairs associated with the Kinesis Video Stream.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type Definition for AWS::KinesisVideo::Stream
 */
export declare function getStreamOutput(args: GetStreamOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetStreamResult>;
export interface GetStreamOutputArgs {
    /**
     * The name of the Kinesis Video stream.
     */
    name: pulumi.Input<string>;
}
