import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::LicenseManager::License
 */
export declare function getLicense(args: GetLicenseArgs, opts?: pulumi.InvokeOptions): Promise<GetLicenseResult>;
export interface GetLicenseArgs {
    /**
     * Amazon Resource Name is a unique name for each resource.
     */
    licenseArn: string;
}
export interface GetLicenseResult {
    /**
     * Beneficiary of the license.
     */
    readonly beneficiary?: string;
    /**
     * Configuration for consumption of the license.
     */
    readonly consumptionConfiguration?: outputs.licensemanager.LicenseConsumptionConfiguration;
    /**
     * License entitlements.
     */
    readonly entitlements?: outputs.licensemanager.LicenseEntitlement[];
    /**
     * Home region for the created license.
     */
    readonly homeRegion?: string;
    /**
     * License issuer.
     */
    readonly issuer?: outputs.licensemanager.LicenseIssuerData;
    /**
     * Amazon Resource Name is a unique name for each resource.
     */
    readonly licenseArn?: string;
    /**
     * License metadata.
     */
    readonly licenseMetadata?: outputs.licensemanager.LicenseMetadata[];
    /**
     * Name for the created license.
     */
    readonly licenseName?: string;
    /**
     * Product name for the created license.
     */
    readonly productName?: string;
    /**
     * ProductSKU of the license.
     */
    readonly productSku?: string;
    /**
     * Date and time range during which the license is valid, in ISO8601-UTC format.
     */
    readonly validity?: outputs.licensemanager.LicenseValidityDateFormat;
    /**
     * The version of the license.
     */
    readonly version?: string;
}
/**
 * Resource Type definition for AWS::LicenseManager::License
 */
export declare function getLicenseOutput(args: GetLicenseOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetLicenseResult>;
export interface GetLicenseOutputArgs {
    /**
     * Amazon Resource Name is a unique name for each resource.
     */
    licenseArn: pulumi.Input<string>;
}
