import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Lightsail::Database
 */
export declare function getDatabase(args: GetDatabaseArgs, opts?: pulumi.InvokeOptions): Promise<GetDatabaseResult>;
export interface GetDatabaseArgs {
    /**
     * The name to use for your new Lightsail database resource.
     */
    relationalDatabaseName: string;
}
export interface GetDatabaseResult {
    /**
     * When true, enables automated backup retention for your database. Updates are applied during the next maintenance window because this can result in an outage.
     */
    readonly backupRetention?: boolean;
    /**
     * Indicates the certificate that needs to be associated with the database.
     */
    readonly caCertificateIdentifier?: string;
    /**
     * The Amazon Resource Name (ARN) of the database (for example, `arn:aws:lightsail:us-east-2:123456789101:RelationalDatabase/244ad76f-8aad-4741-809f-12345EXAMPLE` ).
     */
    readonly databaseArn?: string;
    /**
     * The daily time range during which automated backups are created for your new database if automated backups are enabled.
     */
    readonly preferredBackupWindow?: string;
    /**
     * The weekly time range during which system maintenance can occur on your new database.
     */
    readonly preferredMaintenanceWindow?: string;
    /**
     * Specifies the accessibility options for your new database. A value of true specifies a database that is available to resources outside of your Lightsail account. A value of false specifies a database that is available only to your Lightsail resources in the same region as your database.
     */
    readonly publiclyAccessible?: boolean;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::Lightsail::Database
 */
export declare function getDatabaseOutput(args: GetDatabaseOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDatabaseResult>;
export interface GetDatabaseOutputArgs {
    /**
     * The name to use for your new Lightsail database resource.
     */
    relationalDatabaseName: pulumi.Input<string>;
}
