import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Location::GeofenceCollection Resource Type
 */
export declare class GeofenceCollection extends pulumi.CustomResource {
    /**
     * Get an existing GeofenceCollection resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): GeofenceCollection;
    /**
     * Returns true if the given object is an instance of GeofenceCollection.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is GeofenceCollection;
    /**
     * The Amazon Resource Name (ARN) for the geofence collection resource. Used when you need to specify a resource across all AWS .
     *
     * - Format example: `arn:aws:geo:region:account-id:geofence-collection/ExampleGeofenceCollection`
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Synonym for `Arn` . The Amazon Resource Name (ARN) for the geofence collection resource. Used when you need to specify a resource across all AWS .
     *
     * - Format example: `arn:aws:geo:region:account-id:geofence-collection/ExampleGeofenceCollection`
     */
    readonly collectionArn: pulumi.Output<string>;
    /**
     * A custom name for the geofence collection.
     *
     * Requirements:
     *
     * - Contain only alphanumeric characters (A–Z, a–z, 0–9), hyphens (-), periods (.), and underscores (_).
     * - Must be a unique geofence collection name.
     * - No spaces allowed. For example, `ExampleGeofenceCollection` .
     */
    readonly collectionName: pulumi.Output<string>;
    /**
     * The timestamp for when the geofence collection resource was created in [ISO 8601](https://docs.aws.amazon.com/https://www.iso.org/iso-8601-date-and-time-format.html) format: `YYYY-MM-DDThh:mm:ss.sssZ` .
     */
    readonly createTime: pulumi.Output<string>;
    /**
     * An optional description for the geofence collection.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * A key identifier for an [AWS KMS customer managed key](https://docs.aws.amazon.com/kms/latest/developerguide/create-keys.html) . Enter a key ID, key ARN, alias name, or alias ARN.
     */
    readonly kmsKeyId: pulumi.Output<string | undefined>;
    readonly pricingPlan: pulumi.Output<enums.location.GeofenceCollectionPricingPlan | undefined>;
    /**
     * This shape is deprecated since 2022-02-01: Deprecated. No longer allowed.
     */
    readonly pricingPlanDataSource: pulumi.Output<string | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The timestamp for when the geofence collection resource was last updated in [ISO 8601](https://docs.aws.amazon.com/https://www.iso.org/iso-8601-date-and-time-format.html) format: `YYYY-MM-DDThh:mm:ss.sssZ` .
     */
    readonly updateTime: pulumi.Output<string>;
    /**
     * Create a GeofenceCollection resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: GeofenceCollectionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a GeofenceCollection resource.
 */
export interface GeofenceCollectionArgs {
    /**
     * A custom name for the geofence collection.
     *
     * Requirements:
     *
     * - Contain only alphanumeric characters (A–Z, a–z, 0–9), hyphens (-), periods (.), and underscores (_).
     * - Must be a unique geofence collection name.
     * - No spaces allowed. For example, `ExampleGeofenceCollection` .
     */
    collectionName?: pulumi.Input<string>;
    /**
     * An optional description for the geofence collection.
     */
    description?: pulumi.Input<string>;
    /**
     * A key identifier for an [AWS KMS customer managed key](https://docs.aws.amazon.com/kms/latest/developerguide/create-keys.html) . Enter a key ID, key ARN, alias name, or alias ARN.
     */
    kmsKeyId?: pulumi.Input<string>;
    pricingPlan?: pulumi.Input<enums.location.GeofenceCollectionPricingPlan>;
    /**
     * This shape is deprecated since 2022-02-01: Deprecated. No longer allowed.
     */
    pricingPlanDataSource?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
