import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::MSK::Cluster
 */
export declare function getCluster(args: GetClusterArgs, opts?: pulumi.InvokeOptions): Promise<GetClusterResult>;
export interface GetClusterArgs {
    /**
     * The Amazon Resource Name (ARN) of the MSK cluster.
     */
    arn: string;
}
export interface GetClusterResult {
    /**
     * The Amazon Resource Name (ARN) of the MSK cluster.
     */
    readonly arn?: string;
    /**
     * Information about the broker nodes in the cluster.
     */
    readonly brokerNodeGroupInfo?: outputs.msk.ClusterBrokerNodeGroupInfo;
    /**
     * Includes all client authentication related information.
     */
    readonly clientAuthentication?: outputs.msk.ClusterClientAuthentication;
    /**
     * Represents the configuration that you want MSK to use for the cluster.
     */
    readonly configurationInfo?: outputs.msk.ClusterConfigurationInfo;
    /**
     * The current version of the MSK cluster
     */
    readonly currentVersion?: string;
    /**
     * Includes all encryption-related information.
     */
    readonly encryptionInfo?: outputs.msk.ClusterEncryptionInfo;
    /**
     * Specifies the level of monitoring for the MSK cluster.
     */
    readonly enhancedMonitoring?: enums.msk.ClusterEnhancedMonitoring;
    /**
     * The version of Apache Kafka. You can use Amazon MSK to create clusters that use [supported Apache Kafka versions](https://docs.aws.amazon.com/msk/latest/developerguide/supported-kafka-versions.html) .
     */
    readonly kafkaVersion?: string;
    /**
     * Logging info details for the cluster.
     */
    readonly loggingInfo?: outputs.msk.ClusterLoggingInfo;
    /**
     * The number of broker nodes in the cluster.
     */
    readonly numberOfBrokerNodes?: number;
    /**
     * The settings for open monitoring.
     */
    readonly openMonitoring?: outputs.msk.ClusterOpenMonitoring;
    /**
     * This controls storage mode for supported storage tiers.
     */
    readonly storageMode?: enums.msk.ClusterStorageMode;
    /**
     * A key-value pair to associate with a resource.
     */
    readonly tags?: {
        [key: string]: string;
    };
}
/**
 * Resource Type definition for AWS::MSK::Cluster
 */
export declare function getClusterOutput(args: GetClusterOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetClusterResult>;
export interface GetClusterOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the MSK cluster.
     */
    arn: pulumi.Input<string>;
}
