import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::NimbleStudio::Studio
 */
export declare class Studio extends pulumi.CustomResource {
    /**
     * Get an existing Studio resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Studio;
    /**
     * Returns true if the given object is an instance of Studio.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Studio;
    /**
     * The IAM role that studio admins assume when logging in to the Nimble Studio portal.
     */
    readonly adminRoleArn: pulumi.Output<string>;
    /**
     * A friendly name for the studio.
     */
    readonly displayName: pulumi.Output<string>;
    /**
     * The AWS Region where the studio resource is located. For example, `us-west-2` .
     */
    readonly homeRegion: pulumi.Output<string>;
    /**
     * The IAM Identity Center application client ID that is used to integrate with IAM Identity Center , which enables IAM Identity Center users to log into the  portal.
     */
    readonly ssoClientId: pulumi.Output<string>;
    /**
     * Configuration of the encryption method that is used for the studio.
     */
    readonly studioEncryptionConfiguration: pulumi.Output<outputs.nimblestudio.StudioEncryptionConfiguration | undefined>;
    /**
     * The unique identifier for the studio resource.
     */
    readonly studioId: pulumi.Output<string>;
    /**
     * The name of the studio, as included in the URL when accessing it in the Nimble Studio portal.
     */
    readonly studioName: pulumi.Output<string>;
    /**
     * The unique identifier for the studio resource.
     */
    readonly studioUrl: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The IAM role that studio users assume when logging in to the Nimble Studio portal.
     */
    readonly userRoleArn: pulumi.Output<string>;
    /**
     * Create a Studio resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: StudioArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Studio resource.
 */
export interface StudioArgs {
    /**
     * The IAM role that studio admins assume when logging in to the Nimble Studio portal.
     */
    adminRoleArn: pulumi.Input<string>;
    /**
     * A friendly name for the studio.
     */
    displayName: pulumi.Input<string>;
    /**
     * Configuration of the encryption method that is used for the studio.
     */
    studioEncryptionConfiguration?: pulumi.Input<inputs.nimblestudio.StudioEncryptionConfigurationArgs>;
    /**
     * The name of the studio, as included in the URL when accessing it in the Nimble Studio portal.
     */
    studioName?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) .
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The IAM role that studio users assume when logging in to the Nimble Studio portal.
     */
    userRoleArn: pulumi.Input<string>;
}
