import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * A zero-ETL integration with Amazon Redshift.
 */
export declare function getIntegration(args: GetIntegrationArgs, opts?: pulumi.InvokeOptions): Promise<GetIntegrationResult>;
export interface GetIntegrationArgs {
    /**
     * The ARN of the integration.
     */
    integrationArn: string;
}
export interface GetIntegrationResult {
    /**
     * The time when the integration was created, in Universal Coordinated Time (UTC).
     */
    readonly createTime?: string;
    /**
     * Data filters for the integration. These filters determine which tables from the source database are sent to the target Amazon Redshift data warehouse.
     */
    readonly dataFilter?: string;
    /**
     * A description of the integration.
     */
    readonly description?: string;
    /**
     * The ARN of the integration.
     */
    readonly integrationArn?: string;
    /**
     * The name of the integration.
     */
    readonly integrationName?: string;
    /**
     * A list of tags. For more information, see [Tagging Amazon RDS Resources](https://docs.aws.amazon.com/AmazonRDS/latest/UserGuide/USER_Tagging.html) in the *Amazon RDS User Guide.*.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * A zero-ETL integration with Amazon Redshift.
 */
export declare function getIntegrationOutput(args: GetIntegrationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetIntegrationResult>;
export interface GetIntegrationOutputArgs {
    /**
     * The ARN of the integration.
     */
    integrationArn: pulumi.Input<string>;
}
