import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::SageMaker::Pipeline
 */
export declare function getPipeline(args: GetPipelineArgs, opts?: pulumi.InvokeOptions): Promise<GetPipelineResult>;
export interface GetPipelineArgs {
    /**
     * The name of the Pipeline.
     */
    pipelineName: string;
}
export interface GetPipelineResult {
    /**
     * The parallelism configuration applied to the pipeline.
     */
    readonly parallelismConfiguration?: outputs.sagemaker.ParallelismConfigurationProperties;
    /**
     * The definition of the pipeline. This can be either a JSON string or an Amazon S3 location.
     */
    readonly pipelineDefinition?: outputs.sagemaker.PipelineDefinition0Properties | outputs.sagemaker.PipelineDefinition1Properties;
    /**
     * The description of the Pipeline.
     */
    readonly pipelineDescription?: string;
    /**
     * The display name of the Pipeline.
     */
    readonly pipelineDisplayName?: string;
    /**
     * Role Arn
     */
    readonly roleArn?: string;
    /**
     * The tags of the pipeline.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::SageMaker::Pipeline
 */
export declare function getPipelineOutput(args: GetPipelineOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetPipelineResult>;
export interface GetPipelineOutputArgs {
    /**
     * The name of the Pipeline.
     */
    pipelineName: pulumi.Input<string>;
}
