import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::SageMaker::ModelExplainabilityJobDefinition
 */
export declare class ModelExplainabilityJobDefinition extends pulumi.CustomResource {
    /**
     * Get an existing ModelExplainabilityJobDefinition resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ModelExplainabilityJobDefinition;
    /**
     * Returns true if the given object is an instance of ModelExplainabilityJobDefinition.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ModelExplainabilityJobDefinition;
    /**
     * The time at which the job definition was created.
     */
    readonly creationTime: pulumi.Output<string>;
    readonly endpointName: pulumi.Output<string | undefined>;
    /**
     * The Amazon Resource Name (ARN) of job definition.
     */
    readonly jobDefinitionArn: pulumi.Output<string>;
    /**
     * The name of the model explainability job definition. The name must be unique within an AWS Region in the AWS account.
     */
    readonly jobDefinitionName: pulumi.Output<string | undefined>;
    /**
     * Identifies the resources to deploy for a monitoring job.
     */
    readonly jobResources: pulumi.Output<outputs.sagemaker.ModelExplainabilityJobDefinitionMonitoringResources>;
    /**
     * Configures the model explainability job to run a specified Docker container image.
     */
    readonly modelExplainabilityAppSpecification: pulumi.Output<outputs.sagemaker.ModelExplainabilityJobDefinitionModelExplainabilityAppSpecification>;
    /**
     * The baseline configuration for a model explainability job.
     */
    readonly modelExplainabilityBaselineConfig: pulumi.Output<outputs.sagemaker.ModelExplainabilityJobDefinitionModelExplainabilityBaselineConfig | undefined>;
    /**
     * Inputs for the model explainability job.
     */
    readonly modelExplainabilityJobInput: pulumi.Output<outputs.sagemaker.ModelExplainabilityJobDefinitionModelExplainabilityJobInput>;
    /**
     * The output configuration for monitoring jobs.
     */
    readonly modelExplainabilityJobOutputConfig: pulumi.Output<outputs.sagemaker.ModelExplainabilityJobDefinitionMonitoringOutputConfig>;
    /**
     * Networking options for a model explainability job.
     */
    readonly networkConfig: pulumi.Output<outputs.sagemaker.ModelExplainabilityJobDefinitionNetworkConfig | undefined>;
    /**
     * The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform tasks on your behalf.
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * A time limit for how long the monitoring job is allowed to run before stopping.
     */
    readonly stoppingCondition: pulumi.Output<outputs.sagemaker.ModelExplainabilityJobDefinitionStoppingCondition | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.CreateOnlyTag[] | undefined>;
    /**
     * Create a ModelExplainabilityJobDefinition resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ModelExplainabilityJobDefinitionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ModelExplainabilityJobDefinition resource.
 */
export interface ModelExplainabilityJobDefinitionArgs {
    endpointName?: pulumi.Input<string>;
    /**
     * The name of the model explainability job definition. The name must be unique within an AWS Region in the AWS account.
     */
    jobDefinitionName?: pulumi.Input<string>;
    /**
     * Identifies the resources to deploy for a monitoring job.
     */
    jobResources: pulumi.Input<inputs.sagemaker.ModelExplainabilityJobDefinitionMonitoringResourcesArgs>;
    /**
     * Configures the model explainability job to run a specified Docker container image.
     */
    modelExplainabilityAppSpecification: pulumi.Input<inputs.sagemaker.ModelExplainabilityJobDefinitionModelExplainabilityAppSpecificationArgs>;
    /**
     * The baseline configuration for a model explainability job.
     */
    modelExplainabilityBaselineConfig?: pulumi.Input<inputs.sagemaker.ModelExplainabilityJobDefinitionModelExplainabilityBaselineConfigArgs>;
    /**
     * Inputs for the model explainability job.
     */
    modelExplainabilityJobInput: pulumi.Input<inputs.sagemaker.ModelExplainabilityJobDefinitionModelExplainabilityJobInputArgs>;
    /**
     * The output configuration for monitoring jobs.
     */
    modelExplainabilityJobOutputConfig: pulumi.Input<inputs.sagemaker.ModelExplainabilityJobDefinitionMonitoringOutputConfigArgs>;
    /**
     * Networking options for a model explainability job.
     */
    networkConfig?: pulumi.Input<inputs.sagemaker.ModelExplainabilityJobDefinitionNetworkConfigArgs>;
    /**
     * The Amazon Resource Name (ARN) of an IAM role that Amazon SageMaker can assume to perform tasks on your behalf.
     */
    roleArn: pulumi.Input<string>;
    /**
     * A time limit for how long the monitoring job is allowed to run before stopping.
     */
    stoppingCondition?: pulumi.Input<inputs.sagemaker.ModelExplainabilityJobDefinitionStoppingConditionArgs>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.CreateOnlyTagArgs>[]>;
}
