import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::SageMaker::Pipeline
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myPipeline = new aws_native.sagemaker.Pipeline("myPipeline", {
 *     pipelineName: "<pipeline-name>",
 *     pipelineDisplayName: "<pipeline-display-name>",
 *     pipelineDescription: "<pipeline-description>",
 *     pipelineDefinition: {
 *         pipelineDefinitionS3Location: {
 *             bucket: "<S3-bucket-location>",
 *             key: "<S3-bucket-key>",
 *         },
 *     },
 *     roleArn: "arn:aws:iam::<account-id>:root",
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const myPipeline = new aws_native.sagemaker.Pipeline("myPipeline", {
 *     pipelineName: "<pipeline-name>",
 *     pipelineDisplayName: "<pipeline-display-name>",
 *     pipelineDescription: "<pipeline-description>",
 *     pipelineDefinition: {
 *         pipelineDefinitionBody: "{\"Version\":\"2020-12-01\",\"Parameters\":[{\"Name\":\"InputDataSource\",\"DefaultValue\":\"\"},{\"Name\":\"InstanceCount\",\"Type\":\"Integer\",\"DefaultValue\":1}],\"Steps\":[{\"Name\":\"Training1\",\"Type\":\"Training\",\"Arguments\":{\"InputDataConfig\":[{\"DataSource\":{\"S3DataSource\":{\"S3Uri\":{\"Get\":\"Parameters.InputDataSource\"}}}}],\"OutputDataConfig\":{\"S3OutputPath\":\"s3://my-s3-bucket/\"},\"ResourceConfig\":{\"InstanceType\":\"ml.m5.large\",\"InstanceCount\":{\"Get\":\"Parameters.InstanceCount\"},\"VolumeSizeInGB\":1024}}}]}",
 *     },
 *     roleArn: "arn:aws:iam::<account-id>:root",
 * });
 *
 * ```
 */
export declare class Pipeline extends pulumi.CustomResource {
    /**
     * Get an existing Pipeline resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Pipeline;
    /**
     * Returns true if the given object is an instance of Pipeline.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Pipeline;
    /**
     * The parallelism configuration applied to the pipeline.
     */
    readonly parallelismConfiguration: pulumi.Output<outputs.sagemaker.ParallelismConfigurationProperties | undefined>;
    /**
     * The definition of the pipeline. This can be either a JSON string or an Amazon S3 location.
     */
    readonly pipelineDefinition: pulumi.Output<outputs.sagemaker.PipelineDefinition0Properties | outputs.sagemaker.PipelineDefinition1Properties>;
    /**
     * The description of the Pipeline.
     */
    readonly pipelineDescription: pulumi.Output<string | undefined>;
    /**
     * The display name of the Pipeline.
     */
    readonly pipelineDisplayName: pulumi.Output<string | undefined>;
    /**
     * The name of the Pipeline.
     */
    readonly pipelineName: pulumi.Output<string>;
    /**
     * Role Arn
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * The tags of the pipeline.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Pipeline resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: PipelineArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Pipeline resource.
 */
export interface PipelineArgs {
    /**
     * The parallelism configuration applied to the pipeline.
     */
    parallelismConfiguration?: pulumi.Input<inputs.sagemaker.ParallelismConfigurationPropertiesArgs>;
    /**
     * The definition of the pipeline. This can be either a JSON string or an Amazon S3 location.
     */
    pipelineDefinition: pulumi.Input<inputs.sagemaker.PipelineDefinition0PropertiesArgs | inputs.sagemaker.PipelineDefinition1PropertiesArgs>;
    /**
     * The description of the Pipeline.
     */
    pipelineDescription?: pulumi.Input<string>;
    /**
     * The display name of the Pipeline.
     */
    pipelineDisplayName?: pulumi.Input<string>;
    /**
     * The name of the Pipeline.
     */
    pipelineName?: pulumi.Input<string>;
    /**
     * Role Arn
     */
    roleArn: pulumi.Input<string>;
    /**
     * The tags of the pipeline.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
