import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource schema for AWS::SES::ConfigurationSet.
 */
export declare function getConfigurationSet(args: GetConfigurationSetArgs, opts?: pulumi.InvokeOptions): Promise<GetConfigurationSetResult>;
export interface GetConfigurationSetArgs {
    /**
     * The name of the configuration set.
     */
    name: string;
}
export interface GetConfigurationSetResult {
    /**
     * Specifies the name of the dedicated IP pool to associate with the configuration set and whether messages that use the configuration set are required to use Transport Layer Security (TLS).
     */
    readonly deliveryOptions?: outputs.ses.ConfigurationSetDeliveryOptions;
    /**
     * An object that defines whether or not Amazon SES collects reputation metrics for the emails that you send that use the configuration set.
     */
    readonly reputationOptions?: outputs.ses.ConfigurationSetReputationOptions;
    /**
     * An object that defines whether or not Amazon SES can send email that you send using the configuration set.
     */
    readonly sendingOptions?: outputs.ses.ConfigurationSetSendingOptions;
    /**
     * An object that contains information about the suppression list preferences for your account.
     */
    readonly suppressionOptions?: outputs.ses.ConfigurationSetSuppressionOptions;
    /**
     * An object that defines the open and click tracking options for emails that you send using the configuration set.
     */
    readonly trackingOptions?: outputs.ses.ConfigurationSetTrackingOptions;
    /**
     * The Virtual Deliverability Manager (VDM) options that apply to the configuration set.
     */
    readonly vdmOptions?: outputs.ses.ConfigurationSetVdmOptions;
}
/**
 * Resource schema for AWS::SES::ConfigurationSet.
 */
export declare function getConfigurationSetOutput(args: GetConfigurationSetOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetConfigurationSetResult>;
export interface GetConfigurationSetOutputArgs {
    /**
     * The name of the configuration set.
     */
    name: pulumi.Input<string>;
}
