import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::SSMContacts::ContactChannel
 */
export declare class ContactChannel extends pulumi.CustomResource {
    /**
     * Get an existing ContactChannel resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ContactChannel;
    /**
     * Returns true if the given object is an instance of ContactChannel.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ContactChannel;
    /**
     * The Amazon Resource Name (ARN) of the engagement to a contact channel.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The details that SSM Incident Manager uses when trying to engage the contact channel.
     */
    readonly channelAddress: pulumi.Output<string | undefined>;
    /**
     * The device name. String of 6 to 50 alphabetical, numeric, dash, and underscore characters.
     */
    readonly channelName: pulumi.Output<string | undefined>;
    /**
     * Device type, which specify notification channel. Currently supported values: "SMS", "VOICE", "EMAIL", "CHATBOT.
     */
    readonly channelType: pulumi.Output<enums.ssmcontacts.ContactChannelChannelType | undefined>;
    /**
     * ARN of the contact resource
     */
    readonly contactId: pulumi.Output<string | undefined>;
    /**
     * If you want to activate the channel at a later time, you can choose to defer activation. SSM Incident Manager can't engage your contact channel until it has been activated.
     */
    readonly deferActivation: pulumi.Output<boolean | undefined>;
    /**
     * Create a ContactChannel resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ContactChannelArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ContactChannel resource.
 */
export interface ContactChannelArgs {
    /**
     * The details that SSM Incident Manager uses when trying to engage the contact channel.
     */
    channelAddress?: pulumi.Input<string>;
    /**
     * The device name. String of 6 to 50 alphabetical, numeric, dash, and underscore characters.
     */
    channelName?: pulumi.Input<string>;
    /**
     * Device type, which specify notification channel. Currently supported values: "SMS", "VOICE", "EMAIL", "CHATBOT.
     */
    channelType?: pulumi.Input<enums.ssmcontacts.ContactChannelChannelType>;
    /**
     * ARN of the contact resource
     */
    contactId?: pulumi.Input<string>;
    /**
     * If you want to activate the channel at a later time, you can choose to defer activation. SSM Incident Manager can't engage your contact channel until it has been activated.
     */
    deferActivation?: pulumi.Input<boolean>;
}
