import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource type definition for AWS::SSMIncidents::ReplicationSet
 */
export declare class ReplicationSet extends pulumi.CustomResource {
    /**
     * Get an existing ReplicationSet resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ReplicationSet;
    /**
     * Returns true if the given object is an instance of ReplicationSet.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ReplicationSet;
    /**
     * The ARN of the ReplicationSet.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * Determines if the replication set deletion protection is enabled or not. If deletion protection is enabled, you can't delete the last Region in the replication set.
     */
    readonly deletionProtected: pulumi.Output<boolean | undefined>;
    /**
     * The ReplicationSet configuration.
     */
    readonly regions: pulumi.Output<outputs.ssmincidents.ReplicationSetReplicationRegion[]>;
    /**
     * The tags to apply to the replication set.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a ReplicationSet resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ReplicationSetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ReplicationSet resource.
 */
export interface ReplicationSetArgs {
    /**
     * Determines if the replication set deletion protection is enabled or not. If deletion protection is enabled, you can't delete the last Region in the replication set.
     */
    deletionProtected?: pulumi.Input<boolean>;
    /**
     * The ReplicationSet configuration.
     */
    regions: pulumi.Input<pulumi.Input<inputs.ssmincidents.ReplicationSetReplicationRegionArgs>[]>;
    /**
     * The tags to apply to the replication set.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
