import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource type definition for AWS::SSMIncidents::ResponsePlan
 */
export declare class ResponsePlan extends pulumi.CustomResource {
    /**
     * Get an existing ResponsePlan resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ResponsePlan;
    /**
     * Returns true if the given object is an instance of ResponsePlan.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ResponsePlan;
    /**
     * The list of actions.
     */
    readonly actions: pulumi.Output<outputs.ssmincidents.ResponsePlanAction[] | undefined>;
    /**
     * The ARN of the response plan.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The  chat channel used for collaboration during an incident.
     */
    readonly chatChannel: pulumi.Output<outputs.ssmincidents.ResponsePlanChatChannel | undefined>;
    /**
     * The display name of the response plan.
     */
    readonly displayName: pulumi.Output<string | undefined>;
    /**
     * The list of engagements to use.
     */
    readonly engagements: pulumi.Output<string[] | undefined>;
    /**
     * Details used to create an incident when using this response plan.
     */
    readonly incidentTemplate: pulumi.Output<outputs.ssmincidents.ResponsePlanIncidentTemplate>;
    /**
     * The list of integrations.
     */
    readonly integrations: pulumi.Output<outputs.ssmincidents.ResponsePlanIntegration[] | undefined>;
    /**
     * The name of the response plan.
     */
    readonly name: pulumi.Output<string>;
    /**
     * The tags to apply to the response plan.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a ResponsePlan resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ResponsePlanArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ResponsePlan resource.
 */
export interface ResponsePlanArgs {
    /**
     * The list of actions.
     */
    actions?: pulumi.Input<pulumi.Input<inputs.ssmincidents.ResponsePlanActionArgs>[]>;
    /**
     * The  chat channel used for collaboration during an incident.
     */
    chatChannel?: pulumi.Input<inputs.ssmincidents.ResponsePlanChatChannelArgs>;
    /**
     * The display name of the response plan.
     */
    displayName?: pulumi.Input<string>;
    /**
     * The list of engagements to use.
     */
    engagements?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * Details used to create an incident when using this response plan.
     */
    incidentTemplate: pulumi.Input<inputs.ssmincidents.ResponsePlanIncidentTemplateArgs>;
    /**
     * The list of integrations.
     */
    integrations?: pulumi.Input<pulumi.Input<inputs.ssmincidents.ResponsePlanIntegrationArgs>[]>;
    /**
     * The name of the response plan.
     */
    name?: pulumi.Input<string>;
    /**
     * The tags to apply to the response plan.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
