import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::SystemsManagerSAP::Application
 */
export declare class Application extends pulumi.CustomResource {
    /**
     * Get an existing Application resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Application;
    /**
     * Returns true if the given object is an instance of Application.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Application;
    /**
     * The ID of the application.
     */
    readonly applicationId: pulumi.Output<string>;
    /**
     * The type of the application.
     */
    readonly applicationType: pulumi.Output<enums.systemsmanagersap.ApplicationType>;
    /**
     * The ARN of the SSM-SAP application
     */
    readonly arn: pulumi.Output<string>;
    /**
     * This is an optional parameter for component details to which the SAP ABAP application is attached, such as Web Dispatcher.
     */
    readonly componentsInfo: pulumi.Output<outputs.systemsmanagersap.ApplicationComponentInfo[] | undefined>;
    /**
     * The credentials of the SAP application.
     */
    readonly credentials: pulumi.Output<outputs.systemsmanagersap.ApplicationCredential[] | undefined>;
    /**
     * The ARN of the SAP HANA database
     */
    readonly databaseArn: pulumi.Output<string | undefined>;
    /**
     * The Amazon EC2 instances on which your SAP application is running.
     */
    readonly instances: pulumi.Output<string[] | undefined>;
    /**
     * The SAP instance number of the application.
     */
    readonly sapInstanceNumber: pulumi.Output<string | undefined>;
    /**
     * The System ID of the application.
     */
    readonly sid: pulumi.Output<string | undefined>;
    /**
     * The tags of a SystemsManagerSAP application.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a Application resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ApplicationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Application resource.
 */
export interface ApplicationArgs {
    /**
     * The ID of the application.
     */
    applicationId: pulumi.Input<string>;
    /**
     * The type of the application.
     */
    applicationType: pulumi.Input<enums.systemsmanagersap.ApplicationType>;
    /**
     * This is an optional parameter for component details to which the SAP ABAP application is attached, such as Web Dispatcher.
     */
    componentsInfo?: pulumi.Input<pulumi.Input<inputs.systemsmanagersap.ApplicationComponentInfoArgs>[]>;
    /**
     * The credentials of the SAP application.
     */
    credentials?: pulumi.Input<pulumi.Input<inputs.systemsmanagersap.ApplicationCredentialArgs>[]>;
    /**
     * The ARN of the SAP HANA database
     */
    databaseArn?: pulumi.Input<string>;
    /**
     * The Amazon EC2 instances on which your SAP application is running.
     */
    instances?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The SAP instance number of the application.
     */
    sapInstanceNumber?: pulumi.Input<string>;
    /**
     * The System ID of the application.
     */
    sid?: pulumi.Input<string>;
    /**
     * The tags of a SystemsManagerSAP application.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
