export declare const DocumentClassifierAugmentedManifestsListItemSplit: {
    readonly Train: "TRAIN";
    readonly Test: "TEST";
};
/**
 * The purpose of the data you've provided in the augmented manifest. You can either train or test this data. If you don't specify, the default is train.
 *
 * TRAIN - all of the documents in the manifest will be used for training. If no test documents are provided, Amazon Comprehend will automatically reserve a portion of the training documents for testing.
 *
 * TEST - all of the documents in the manifest will be used for testing.
 */
export type DocumentClassifierAugmentedManifestsListItemSplit = (typeof DocumentClassifierAugmentedManifestsListItemSplit)[keyof typeof DocumentClassifierAugmentedManifestsListItemSplit];
export declare const DocumentClassifierDocumentReaderConfigDocumentReadAction: {
    readonly TextractDetectDocumentText: "TEXTRACT_DETECT_DOCUMENT_TEXT";
    readonly TextractAnalyzeDocument: "TEXTRACT_ANALYZE_DOCUMENT";
};
/**
 * This field defines the Amazon Textract API operation that Amazon Comprehend uses to extract text from PDF files and image files. Enter one of the following values:
 *
 * - `TEXTRACT_DETECT_DOCUMENT_TEXT` - The Amazon Comprehend service uses the `DetectDocumentText` API operation.
 * - `TEXTRACT_ANALYZE_DOCUMENT` - The Amazon Comprehend service uses the `AnalyzeDocument` API operation.
 */
export type DocumentClassifierDocumentReaderConfigDocumentReadAction = (typeof DocumentClassifierDocumentReaderConfigDocumentReadAction)[keyof typeof DocumentClassifierDocumentReaderConfigDocumentReadAction];
export declare const DocumentClassifierDocumentReaderConfigDocumentReadMode: {
    readonly ServiceDefault: "SERVICE_DEFAULT";
    readonly ForceDocumentReadAction: "FORCE_DOCUMENT_READ_ACTION";
};
/**
 * Determines the text extraction actions for PDF files. Enter one of the following values:
 *
 * - `SERVICE_DEFAULT` - use the Amazon Comprehend service defaults for PDF files.
 * - `FORCE_DOCUMENT_READ_ACTION` - Amazon Comprehend uses the Textract API specified by DocumentReadAction for all PDF files, including digital PDF files.
 */
export type DocumentClassifierDocumentReaderConfigDocumentReadMode = (typeof DocumentClassifierDocumentReaderConfigDocumentReadMode)[keyof typeof DocumentClassifierDocumentReaderConfigDocumentReadMode];
export declare const DocumentClassifierDocumentReaderConfigFeatureTypesItem: {
    readonly Tables: "TABLES";
    readonly Forms: "FORMS";
};
export type DocumentClassifierDocumentReaderConfigFeatureTypesItem = (typeof DocumentClassifierDocumentReaderConfigFeatureTypesItem)[keyof typeof DocumentClassifierDocumentReaderConfigFeatureTypesItem];
export declare const DocumentClassifierInputDataConfigDataFormat: {
    readonly ComprehendCsv: "COMPREHEND_CSV";
    readonly AugmentedManifest: "AUGMENTED_MANIFEST";
};
/**
 * The format of your training data:
 *
 * - `COMPREHEND_CSV` : A two-column CSV file, where labels are provided in the first column, and documents are provided in the second. If you use this value, you must provide the `S3Uri` parameter in your request.
 * - `AUGMENTED_MANIFEST` : A labeled dataset that is produced by Amazon SageMaker Ground Truth. This file is in JSON lines format. Each line is a complete JSON object that contains a training document and its associated labels.
 *
 * If you use this value, you must provide the `AugmentedManifests` parameter in your request.
 *
 * If you don't specify a value, Amazon Comprehend uses `COMPREHEND_CSV` as the default.
 */
export type DocumentClassifierInputDataConfigDataFormat = (typeof DocumentClassifierInputDataConfigDataFormat)[keyof typeof DocumentClassifierInputDataConfigDataFormat];
export declare const DocumentClassifierInputDataConfigDocumentType: {
    readonly PlainTextDocument: "PLAIN_TEXT_DOCUMENT";
    readonly SemiStructuredDocument: "SEMI_STRUCTURED_DOCUMENT";
};
/**
 * The type of input documents for training the model. Provide plain-text documents to create a plain-text model, and provide semi-structured documents to create a native document model.
 */
export type DocumentClassifierInputDataConfigDocumentType = (typeof DocumentClassifierInputDataConfigDocumentType)[keyof typeof DocumentClassifierInputDataConfigDocumentType];
export declare const DocumentClassifierLanguageCode: {
    readonly En: "en";
    readonly Es: "es";
    readonly Fr: "fr";
    readonly It: "it";
    readonly De: "de";
    readonly Pt: "pt";
};
/**
 * The language of the input documents. You can specify any of the languages supported by Amazon Comprehend. All documents must be in the same language.
 */
export type DocumentClassifierLanguageCode = (typeof DocumentClassifierLanguageCode)[keyof typeof DocumentClassifierLanguageCode];
export declare const DocumentClassifierMode: {
    readonly MultiClass: "MULTI_CLASS";
    readonly MultiLabel: "MULTI_LABEL";
};
/**
 * Indicates the mode in which the classifier will be trained. The classifier can be trained in multi-class (single-label) mode or multi-label mode. Multi-class mode identifies a single class label for each document and multi-label mode identifies one or more class labels for each document. Multiple labels for an individual document are separated by a delimiter. The default delimiter between labels is a pipe (|).
 */
export type DocumentClassifierMode = (typeof DocumentClassifierMode)[keyof typeof DocumentClassifierMode];
export declare const FlywheelDocumentClassificationConfigMode: {
    readonly MultiClass: "MULTI_CLASS";
    readonly MultiLabel: "MULTI_LABEL";
};
/**
 * Classification mode indicates whether the documents are `MULTI_CLASS` or `MULTI_LABEL` .
 */
export type FlywheelDocumentClassificationConfigMode = (typeof FlywheelDocumentClassificationConfigMode)[keyof typeof FlywheelDocumentClassificationConfigMode];
export declare const FlywheelModelType: {
    readonly DocumentClassifier: "DOCUMENT_CLASSIFIER";
    readonly EntityRecognizer: "ENTITY_RECOGNIZER";
};
/**
 * Model type of the flywheel's model.
 */
export type FlywheelModelType = (typeof FlywheelModelType)[keyof typeof FlywheelModelType];
export declare const FlywheelTaskConfigLanguageCode: {
    readonly En: "en";
    readonly Es: "es";
    readonly Fr: "fr";
    readonly It: "it";
    readonly De: "de";
    readonly Pt: "pt";
};
/**
 * Language code for the language that the model supports.
 */
export type FlywheelTaskConfigLanguageCode = (typeof FlywheelTaskConfigLanguageCode)[keyof typeof FlywheelTaskConfigLanguageCode];
