import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::GuardDuty::MalwareProtectionPlan
 */
export declare function getMalwareProtectionPlan(args: GetMalwareProtectionPlanArgs, opts?: pulumi.InvokeOptions): Promise<GetMalwareProtectionPlanResult>;
export interface GetMalwareProtectionPlanArgs {
    /**
     * A unique identifier associated with Malware Protection plan resource.
     */
    malwareProtectionPlanId: string;
}
export interface GetMalwareProtectionPlanResult {
    /**
     * Specifies the action that is to be applied to the Malware Protection plan resource.
     */
    readonly actions?: outputs.guardduty.MalwareProtectionPlanCfnActions;
    /**
     * Amazon Resource Name (ARN) of the protected resource.
     */
    readonly arn?: string;
    /**
     * The timestamp when the Malware Protection plan resource was created.
     */
    readonly createdAt?: string;
    /**
     * A unique identifier associated with Malware Protection plan resource.
     */
    readonly malwareProtectionPlanId?: string;
    /**
     * Information about the protected resource. Presently, S3Bucket is the only supported protected resource.
     */
    readonly protectedResource?: outputs.guardduty.MalwareProtectionPlanCfnProtectedResource;
    /**
     * IAM role that includes the permissions required to scan and (optionally) add tags to the associated protected resource.
     */
    readonly role?: string;
    /**
     * Status of the Malware Protection plan resource.
     */
    readonly status?: string;
    /**
     * Status details associated with the Malware Protection plan resource status.
     */
    readonly statusReasons?: outputs.guardduty.MalwareProtectionPlanCfnStatusReasons[];
    /**
     * The tags to be added to the created Malware Protection plan resource. Each tag consists of a key and an optional value, both of which you need to specify.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::GuardDuty::MalwareProtectionPlan
 */
export declare function getMalwareProtectionPlanOutput(args: GetMalwareProtectionPlanOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetMalwareProtectionPlanResult>;
export interface GetMalwareProtectionPlanOutputArgs {
    /**
     * A unique identifier associated with Malware Protection plan resource.
     */
    malwareProtectionPlanId: pulumi.Input<string>;
}
